# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/martinrusilowicz/work/apps/bio42/bio42_gui/forms/designer/frm_neo4j_wizard_designer.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def __init__(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(973, 603)
        Dialog.setStyleSheet("/**\n"
"    PURPOSE:\n"
"        This is the default style-sheet used by all Intermake dialogues.\n"
"        It needs to be processed by css_processing.py before it can be used. \n"
"        It can be retrieved in processed form by the `intermake_gui.default_style_sheet()` function.\n"
"\n"
"    USAGE:    \n"
"        You can replace this stylesheet with your own.\n"
"        If you blank the contents of this stylesheet, the OSs default controls will be used.\n"
"        If you delete this stylesheet, the program will crash.\n"
"        \n"
"    EXTENSIONS:\n"
"        Normally not permitted in Qt, the following values are read through Intermake.\n"
"            * #DEFINE X Y                    - replaces all text `X` with `Y`\n"
"            * #WHEN X Y Z                    - only executes the following lines if the current\n"
"                                               section is any of `X` `Y` or `Z`.\n"
"                                               The section is specified when the user selects a\n"
"                                               stylesheet.\n"
"            * `QApplication.style`           - one of the Qt styles\n"
"            * `QApplication.small_icon_size` - the menu icon size, permitted only if `style` is set\n"
"            * `QMdiArea.background`          - colour of the Mdi area\n"
"\n"
"    DETAILS:\n"
"        Follow standard Qt stylesheet guidelines.\n"
"        \n"
"        The `:root` section defines constants that may be used elsewhere. These constants are\n"
"        substituted during the the processing stage and the `:root` section is removed.\n"
"        \n"
"        Intermake controls may have a string property named \"theme\" assigned to to certain widgets.\n"
"        This specifies that a unique appearance for the widget is intended:\n"
"        \n"
"        WIDGET        | THEME             | APPEARANCE (GUIDE)            | USAGE (GUIDE)\n"
"        --------------+-------------------+-------------------------------+-------------------------------\n"
"        QLabel        | heading           | border, big, bold             | section titles \n"
"        QLabel        | subheading        | border, big, bold             | section titles \n"
"        QTextEdit     | console           | monospaced, black background  | code, console output\n"
"        QPushButton   | completed         |                               |\n"
"        QPushButton   | cancel            | red                           | abort button\n"
"        QFrame        | header            | border                        | section titles\n"
"        QFrame        | contents          | white                         | with objects in\n"
"        QToolButton   | listbutton        | condensed                     | buttons in lists\n"
"        QToolButton   | help              | help icon                     | help buttons\n"
"        QLabel        | helpbox           | tooltip background            | help labels\n"
"        QLabel        | icon              | background suitable for image | label showing an icon\n"
"        QLabel        | warning           | yellow background, red text   | warning messages     \n"
"        QMdiArea      | empty             | darker                        | when MDI area has no windows\n"
"        QToolButton   | combo             | white                         | when button presents a selection menu\n"
"        QToolButton   | item              | white background, borderless  | button in a \"contents\" frame, like a list item\n"
"*/\n"
"\n"
"\n"
"\n"
"QMdiArea\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"listbutton\"]\n"
"{\n"
"    background   : #40C0FF;\n"
"    border-style : outset;\n"
"    border-width : 2px;\n"
"    border-color : transparent;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::hover\n"
"{\n"
"    background   : #B0D5E8;\n"
"    border-color : blue;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::pressed\n"
"{\n"
"    background   : #0040C0;\n"
"    border-style : inset;\n"
"}\n"
"\n"
"QLabel[style=\"icon\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QFrame[style=\"title\"]\n"
"{\n"
"    margin-top     : 16px;\n"
"    margin-bottom  : 4px;\n"
"    margin-left    : 0px;\n"
"    margin-right   : 0px;\n"
"    border-radius  : 0px;\n"
"    border-bottom  : 2px solid silver;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    padding-top    : 2px;\n"
"    padding-bottom : 2px;\n"
"    padding-left   : -4px;\n"
"    padding-right  : 0px;\n"
"    color          : black;\n"
"    font-size      : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title\"], QFrame[style=\"title\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 4px;\n"
"    margin        : 2px;\n"
"    padding       : 2px;\n"
"    color         : black;\n"
"    font-size     : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title-embeded\"]\n"
"{\n"
"    background : #EEEEEE;\n"
"    color      : black;\n"
"    font-size  : 18px;\n"
"}\n"
"\n"
"\n"
"\n"
"\n"
"QLabel[style=\"helpbox\"]\n"
"{\n"
"    background    : transparent;\n"
"    color         : steelblue;\n"
"    padding       : 2px;\n"
"    border-radius : 4px;\n"
"}\n"
"\n"
"QLabel[style=\"subheading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    font-style: italic;\n"
"}\n"
"\n"
"QLabel[style=\"heading\"], QPushButton[style=\"heading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    border-bottom  : 1px solid #404040;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    color: #404040;\n"
"}\n"
"\n"
"\n"
"QTextEdit[style=\"console\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"    background : black;\n"
"    color      : white;\n"
"}\n"
"\n"
"QTextEdit[style=\"monospaced\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"}\n"
"\n"
"QPushButton[style=\"completed\"]\n"
"{\n"
"    background    : #00C080;\n"
"    border-color  : #00C080; \n"
"}\n"
"\n"
"QPushButton[style=\"cancel\"]\n"
"{\n"
"    background    : #C00000;\n"
"    color         : white;\n"
"    padding       : 8px;\n"
"    border-color  : white;\n"
"    border-width  : 1px;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QMdiArea[style=\"empty\"]\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"QLabel[style=\"warning\"]\n"
"{\n"
"    background       : #FFFFD0;\n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"    image            : url(\":/intermake/warning.svg\");\n"
"    image-position   : left;\n"
"    qproperty-indent : 24;\n"
"}\n"
"\n"
"QLabel[style=\"warning_no_icon\"]\n"
"{\n"
"    background       : #FFFF80;\n"
"    color            : #800000;          \n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"}\n"
"\n"
"QToolButton[style=\"dropdown\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/dropdown.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"refresh\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/refresh.svg);\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"combo\"]\n"
"{\n"
"    background: white;\n"
"}\n"
"\n"
"QFrame[style=\"contents\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px solid white;\n"
"    color: black;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"    border: 1px dotted #8080FF;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:pressed\n"
"{\n"
"    background: #B0D5E8;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]\n"
"{\n"
"    border: 1px solid transparent;\n"
"    background: transparent;\n"
"    qproperty-icon            : url(:/intermake/help.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:hover\n"
"{\n"
"    border: 1px outset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:pressed\n"
"{\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]\n"
"{\n"
"    background: transparent;\n"
"    border: none;\n"
"    color: blue;\n"
"    padding: 4px;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:pressed\n"
"{\n"
"    color: red;\n"
"    text-decoration: underline;\n"
"    border: 1px solid blue;\n"
"}")
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.TAB_MAIN = QtWidgets.QTabWidget(Dialog)
        self.TAB_MAIN.setDocumentMode(True)
        self.TAB_MAIN.setObjectName("TAB_MAIN")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_16 = QtWidgets.QLabel(self.tab)
        self.label_16.setObjectName("label_16")
        self.verticalLayout_2.addWidget(self.label_16)
        self.label_15 = QtWidgets.QLabel(self.tab)
        self.label_15.setObjectName("label_15")
        self.verticalLayout_2.addWidget(self.label_15)
        self.BTN_BEGIN = QtWidgets.QCommandLinkButton(self.tab)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/bio42/next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_BEGIN.setIcon(icon)
        self.BTN_BEGIN.setIconSize(QtCore.QSize(32, 32))
        self.BTN_BEGIN.setAutoDefault(False)
        self.BTN_BEGIN.setObjectName("BTN_BEGIN")
        self.verticalLayout_2.addWidget(self.BTN_BEGIN)
        spacerItem = QtWidgets.QSpacerItem(20, 942, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem)
        self.TAB_MAIN.addTab(self.tab, "")
        self.tab_2 = QtWidgets.QWidget()
        self.tab_2.setObjectName("tab_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.tab_2)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_6 = QtWidgets.QLabel(self.tab_2)
        self.label_6.setObjectName("label_6")
        self.verticalLayout_3.addWidget(self.label_6)
        self.label_9 = QtWidgets.QLabel(self.tab_2)
        self.label_9.setObjectName("label_9")
        self.verticalLayout_3.addWidget(self.label_9)
        self.BTN_OPEN_DOWNLOAD = QtWidgets.QPushButton(self.tab_2)
        self.BTN_OPEN_DOWNLOAD.setStyleSheet("margin-left:32px;")
        self.BTN_OPEN_DOWNLOAD.setObjectName("BTN_OPEN_DOWNLOAD")
        self.verticalLayout_3.addWidget(self.BTN_OPEN_DOWNLOAD, 0, QtCore.Qt.AlignLeft)
        self.label_17 = QtWidgets.QLabel(self.tab_2)
        self.label_17.setObjectName("label_17")
        self.verticalLayout_3.addWidget(self.label_17)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(8, 8, 8, 8)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.TXT_DOWNLOAD = QtWidgets.QLineEdit(self.tab_2)
        self.TXT_DOWNLOAD.setObjectName("TXT_DOWNLOAD")
        self.horizontalLayout.addWidget(self.TXT_DOWNLOAD)
        self.BTN_BROWSE_DOWNLOAD = QtWidgets.QPushButton(self.tab_2)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/bio42/browse.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_BROWSE_DOWNLOAD.setIcon(icon1)
        self.BTN_BROWSE_DOWNLOAD.setAutoDefault(False)
        self.BTN_BROWSE_DOWNLOAD.setObjectName("BTN_BROWSE_DOWNLOAD")
        self.horizontalLayout.addWidget(self.BTN_BROWSE_DOWNLOAD)
        self.verticalLayout_3.addLayout(self.horizontalLayout)
        self.BTN_VERIFY_DOWNLOAD = QtWidgets.QCommandLinkButton(self.tab_2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/bio42/verify.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_VERIFY_DOWNLOAD.setIcon(icon2)
        self.BTN_VERIFY_DOWNLOAD.setIconSize(QtCore.QSize(32, 32))
        self.BTN_VERIFY_DOWNLOAD.setAutoDefault(False)
        self.BTN_VERIFY_DOWNLOAD.setObjectName("BTN_VERIFY_DOWNLOAD")
        self.verticalLayout_3.addWidget(self.BTN_VERIFY_DOWNLOAD)
        spacerItem1 = QtWidgets.QSpacerItem(20, 890, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.TAB_MAIN.addTab(self.tab_2, "")
        self.tab_3 = QtWidgets.QWidget()
        self.tab_3.setObjectName("tab_3")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tab_3)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_7 = QtWidgets.QLabel(self.tab_3)
        self.label_7.setObjectName("label_7")
        self.verticalLayout_4.addWidget(self.label_7)
        self.label_8 = QtWidgets.QLabel(self.tab_3)
        self.label_8.setObjectName("label_8")
        self.verticalLayout_4.addWidget(self.label_8)
        self.BTN_START = QtWidgets.QCommandLinkButton(self.tab_3)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/bio42/start.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_START.setIcon(icon3)
        self.BTN_START.setIconSize(QtCore.QSize(32, 32))
        self.BTN_START.setAutoDefault(False)
        self.BTN_START.setObjectName("BTN_START")
        self.verticalLayout_4.addWidget(self.BTN_START)
        spacerItem2 = QtWidgets.QSpacerItem(20, 419, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_4.addItem(spacerItem2)
        self.TAB_MAIN.addTab(self.tab_3, "")
        self.tab_4 = QtWidgets.QWidget()
        self.tab_4.setObjectName("tab_4")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tab_4)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.label_10 = QtWidgets.QLabel(self.tab_4)
        self.label_10.setObjectName("label_10")
        self.verticalLayout_5.addWidget(self.label_10)
        self.label_11 = QtWidgets.QLabel(self.tab_4)
        self.label_11.setObjectName("label_11")
        self.verticalLayout_5.addWidget(self.label_11)
        self.BTN_OPEN_LOGON = QtWidgets.QPushButton(self.tab_4)
        self.BTN_OPEN_LOGON.setObjectName("BTN_OPEN_LOGON")
        self.verticalLayout_5.addWidget(self.BTN_OPEN_LOGON, 0, QtCore.Qt.AlignLeft)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setContentsMargins(8, 8, 8, 8)
        self.gridLayout.setObjectName("gridLayout")
        self.label_4 = QtWidgets.QLabel(self.tab_4)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.tab_4)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 0, 1, 1)
        self.TXT_USERNAME = QtWidgets.QLineEdit(self.tab_4)
        self.TXT_USERNAME.setObjectName("TXT_USERNAME")
        self.gridLayout.addWidget(self.TXT_USERNAME, 0, 1, 1, 1)
        self.TXT_PASSWORD = QtWidgets.QLineEdit(self.tab_4)
        self.TXT_PASSWORD.setEchoMode(QtWidgets.QLineEdit.Password)
        self.TXT_PASSWORD.setObjectName("TXT_PASSWORD")
        self.gridLayout.addWidget(self.TXT_PASSWORD, 1, 1, 1, 1)
        self.verticalLayout_5.addLayout(self.gridLayout)
        self.label_18 = QtWidgets.QLabel(self.tab_4)
        self.label_18.setObjectName("label_18")
        self.verticalLayout_5.addWidget(self.label_18)
        self.BTN_VERIFY_LOGON = QtWidgets.QCommandLinkButton(self.tab_4)
        self.BTN_VERIFY_LOGON.setIcon(icon2)
        self.BTN_VERIFY_LOGON.setIconSize(QtCore.QSize(32, 32))
        self.BTN_VERIFY_LOGON.setAutoDefault(False)
        self.BTN_VERIFY_LOGON.setObjectName("BTN_VERIFY_LOGON")
        self.verticalLayout_5.addWidget(self.BTN_VERIFY_LOGON)
        spacerItem3 = QtWidgets.QSpacerItem(20, 191, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_5.addItem(spacerItem3)
        self.TAB_MAIN.addTab(self.tab_4, "")
        self.TAB_COMPLETED = QtWidgets.QWidget()
        self.TAB_COMPLETED.setObjectName("TAB_COMPLETED")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.TAB_COMPLETED)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.label_12 = QtWidgets.QLabel(self.TAB_COMPLETED)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_6.addWidget(self.label_12)
        self.LBL_SAVE = QtWidgets.QLabel(self.TAB_COMPLETED)
        self.LBL_SAVE.setObjectName("LBL_SAVE")
        self.verticalLayout_6.addWidget(self.LBL_SAVE)
        self.BTN_SAVE = QtWidgets.QCommandLinkButton(self.TAB_COMPLETED)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/bio42/save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SAVE.setIcon(icon4)
        self.BTN_SAVE.setIconSize(QtCore.QSize(32, 32))
        self.BTN_SAVE.setAutoDefault(False)
        self.BTN_SAVE.setObjectName("BTN_SAVE")
        self.verticalLayout_6.addWidget(self.BTN_SAVE)
        spacerItem4 = QtWidgets.QSpacerItem(20, 435, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem4)
        self.TAB_MAIN.addTab(self.TAB_COMPLETED, "")
        self.tab_5 = QtWidgets.QWidget()
        self.tab_5.setObjectName("tab_5")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.tab_5)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.label_13 = QtWidgets.QLabel(self.tab_5)
        self.label_13.setObjectName("label_13")
        self.verticalLayout_7.addWidget(self.label_13)
        self.LBL_SAVE_2 = QtWidgets.QLabel(self.tab_5)
        self.LBL_SAVE_2.setObjectName("LBL_SAVE_2")
        self.verticalLayout_7.addWidget(self.LBL_SAVE_2)
        self.BTN_OPTIMISE = QtWidgets.QCommandLinkButton(self.tab_5)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/bio42/optimise.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_OPTIMISE.setIcon(icon5)
        self.BTN_OPTIMISE.setIconSize(QtCore.QSize(32, 32))
        self.BTN_OPTIMISE.setAutoDefault(False)
        self.BTN_OPTIMISE.setObjectName("BTN_OPTIMISE")
        self.verticalLayout_7.addWidget(self.BTN_OPTIMISE)
        self.BTN_DONT_OPTIMISE = QtWidgets.QCommandLinkButton(self.tab_5)
        self.BTN_DONT_OPTIMISE.setIcon(icon)
        self.BTN_DONT_OPTIMISE.setIconSize(QtCore.QSize(32, 32))
        self.BTN_DONT_OPTIMISE.setAutoDefault(False)
        self.BTN_DONT_OPTIMISE.setObjectName("BTN_DONT_OPTIMISE")
        self.verticalLayout_7.addWidget(self.BTN_DONT_OPTIMISE)
        self.LBL_FINISHED = QtWidgets.QLabel(self.tab_5)
        self.LBL_FINISHED.setObjectName("LBL_FINISHED")
        self.verticalLayout_7.addWidget(self.LBL_FINISHED)
        spacerItem5 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem5)
        self.TAB_MAIN.addTab(self.tab_5, "")
        self.verticalLayout.addWidget(self.TAB_MAIN)

        self.retranslateUi(Dialog)
        self.TAB_MAIN.setCurrentIndex(5)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.label_16.setText(_translate("Dialog", "Introduction"))
        self.label_16.setProperty("style", _translate("Dialog", "heading"))
        self.label_15.setText(_translate("Dialog", "<html><head/><body><p>This wizard will guide you through configuring a Neo4j server.</p><p>If you prefer, you can close this dialogue and configure your control_server manually.</p><p>Click <span style=\" font-weight:600;\">begin</span> to begin.</p></body></html>"))
        self.label_15.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_BEGIN.setText(_translate("Dialog", "Begin"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.tab), _translate("Dialog", "Introduction"))
        self.label_6.setText(_translate("Dialog", "Step 1: Download Neo4j"))
        self.label_6.setProperty("style", _translate("Dialog", "heading"))
        self.label_9.setText(_translate("Dialog", "<html>\n"
"<body>\n"
"<p>Download the <b>Neo4j server</b> (<i>.zip</i>) from the link below.</p>\n"
"<p>Make sure to:\n"
"<ul>\n"
"<li>download the <b>server</b> version - <b>not</b> the desktop version</li>\n"
"<li><b>unzip</b> the downloaded package!</li>\n"
"</p></body></html>"))
        self.label_9.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_OPEN_DOWNLOAD.setText(_translate("Dialog", "https://neo4j.com/download/"))
        self.BTN_OPEN_DOWNLOAD.setProperty("style", _translate("Dialog", "link"))
        self.label_17.setText(_translate("Dialog", "<html><head/><body><p>When you are done, tell me where you unzipped Neo4j to and click <span style=\" font-weight:600;\">verify </span>to continue the wizard.</p></body></html>"))
        self.label_17.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_BROWSE_DOWNLOAD.setText(_translate("Dialog", "Browse"))
        self.BTN_VERIFY_DOWNLOAD.setText(_translate("Dialog", "Verify"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.tab_2), _translate("Dialog", "Download"))
        self.label_7.setText(_translate("Dialog", "Step 2: Start Neo4j"))
        self.label_7.setProperty("style", _translate("Dialog", "heading"))
        self.label_8.setText(_translate("Dialog", "<html><head/><body><p>Click the <span style=\" font-weight:600;\">start</span> button to start the server and continue the wizard.</p><p>If you have already started the server yourself, clicking <span style=\" font-weight:600;\">start </span>will verify your server is running instead.</p></body></html>"))
        self.label_8.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_START.setText(_translate("Dialog", "Start"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.tab_3), _translate("Dialog", "Start"))
        self.label_10.setText(_translate("Dialog", "Step 3: Configure logon"))
        self.label_10.setProperty("style", _translate("Dialog", "heading"))
        self.label_11.setText(_translate("Dialog", "<html><head/><body><p>We should change the default password.<br/>The default credentials are:</p><ul style=\"margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;\"><li style=\" margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">user name</span>: <span style=\" font-family:\'Monaco\';\">neo4j</span></li><li style=\" margin-top:0px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-style:italic;\">password</span>: <span style=\" font-family:\'Monaco\';\">neo4j</span></li></ul><p>Click the link and change your password.<br/>When you are done, come back here and let me know the details, if possible they\'ll be secured using your operating system\'s secure keyring.</p></body></html>"))
        self.label_11.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_OPEN_LOGON.setText(_translate("Dialog", "http://127.0.0.1:7474"))
        self.BTN_OPEN_LOGON.setProperty("style", _translate("Dialog", "link"))
        self.label_4.setText(_translate("Dialog", "Password"))
        self.label_3.setText(_translate("Dialog", "Username"))
        self.TXT_USERNAME.setText(_translate("Dialog", "neo4j"))
        self.label_18.setText(_translate("Dialog", "<html><head/><body><p>When you are done, click <span style=\" font-weight:600;\">verify</span> to continue.</p></body></html>"))
        self.label_18.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_VERIFY_LOGON.setText(_translate("Dialog", "Verify"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.tab_4), _translate("Dialog", "Logon"))
        self.label_12.setText(_translate("Dialog", "Almost there..."))
        self.label_12.setProperty("style", _translate("Dialog", "heading"))
        self.LBL_SAVE.setText(_translate("Dialog", "<html><head/><body><p>Click <span style=\" font-weight:600;\">save</span> to save your connection information and continue.</p></body></html>"))
        self.LBL_SAVE.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_SAVE.setText(_translate("Dialog", "Save"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.TAB_COMPLETED), _translate("Dialog", "Save"))
        self.label_13.setText(_translate("Dialog", "Step 4: Optimise"))
        self.label_13.setProperty("style", _translate("Dialog", "heading"))
        self.LBL_SAVE_2.setText(_translate("Dialog", "<html><head/><body><p>Click <span style=\" font-weight:600;\">create indexes</span> to optimise your database and create the Bio42 schema.</p><p>This step is optional, an unoptimised database will still work and you can always perform this step later.</p></body></html>"))
        self.LBL_SAVE_2.setProperty("style", _translate("Dialog", "helpbox"))
        self.BTN_OPTIMISE.setText(_translate("Dialog", "Optimize"))
        self.BTN_DONT_OPTIMISE.setText(_translate("Dialog", "Don\'t optimise"))
        self.LBL_FINISHED.setText(_translate("Dialog", "<html><head/><body><p>All done, you may now close the wizard.</p></body></html>"))
        self.LBL_FINISHED.setProperty("style", _translate("Dialog", "helpbox"))
        self.TAB_MAIN.setTabText(self.TAB_MAIN.indexOf(self.tab_5), _translate("Dialog", "Optimize"))





# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/martinrusilowicz/work/apps/bio42/bio42_gui/forms/designer/frm_query_browser_designer.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def __init__(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1281, 819)
        Dialog.setStyleSheet("/**\n"
"    PURPOSE:\n"
"        This is the default style-sheet used by all Intermake dialogues.\n"
"        It needs to be processed by css_processing.py before it can be used. \n"
"        It can be retrieved in processed form by the `intermake_gui.default_style_sheet()` function.\n"
"\n"
"    USAGE:    \n"
"        You can replace this stylesheet with your own.\n"
"        If you blank the contents of this stylesheet, the OSs default controls will be used.\n"
"        If you delete this stylesheet, the program will crash.\n"
"        \n"
"    EXTENSIONS:\n"
"        Normally not permitted in Qt, the following values are read through Intermake.\n"
"            * #DEFINE X Y                    - replaces all text `X` with `Y`\n"
"            * #WHEN X Y Z                    - only executes the following lines if the current\n"
"                                               section is any of `X` `Y` or `Z`.\n"
"                                               The section is specified when the user selects a\n"
"                                               stylesheet.\n"
"            * `QApplication.style`           - one of the Qt styles\n"
"            * `QApplication.small_icon_size` - the menu icon size, permitted only if `style` is set\n"
"            * `QMdiArea.background`          - colour of the Mdi area\n"
"\n"
"    DETAILS:\n"
"        Follow standard Qt stylesheet guidelines.\n"
"        \n"
"        The `:root` section defines constants that may be used elsewhere. These constants are\n"
"        substituted during the the processing stage and the `:root` section is removed.\n"
"        \n"
"        Intermake controls may have a string property named \"theme\" assigned to to certain widgets.\n"
"        This specifies that a unique appearance for the widget is intended:\n"
"        \n"
"        WIDGET           | THEME             | APPEARANCE (GUIDE)            | USAGE (GUIDE)\n"
"        -----------------+-------------------+-------------------------------+-------------------------------\n"
"        QLabel           | heading           | border, big, bold             | section titles \n"
"        QLabel           | subheading        | border, big, bold             | section titles \n"
"        QTextEdit        | console           | monospaced, black background  | code, console output\n"
"        QPushButton      | completed         |                               |\n"
"        QPushButton      | cancel            | red                           | abort button\n"
"        QFrame           | header            | border                        | section titles\n"
"        QFrame           | contents          | white                         | with objects in\n"
"        QToolButton      | listbutton        | condensed                     | buttons in lists\n"
"        QToolButton      | help              | help icon                     | help buttons\n"
"        QLabel           | helpbox           | tooltip background            | help labels\n"
"        QLabel           | icon              | background suitable for image | label showing an icon\n"
"        QLabel           | warning           | yellow background, red text   | warning messages     \n"
"        QMdiArea         | empty             | darker                        | when MDI area has no windows\n"
"        QToolButton      | combo             | white                         | when button presents a selection menu\n"
"        QToolButton      | item              | white background, borderless  | button in a \"contents\" frame, like a list item\n"
"        QFrame           | helpbox           | yellow background             | frame contains help\n"
"        QFrame           | sidearea          | gray                          | behave like document-mode tab bar\n"
"        QAbstractButton  | expander          | double down / up arrow        | button expands current window frame           \n"
"*/\n"
"\n"
"\n"
"\n"
"QMdiArea\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"listbutton\"]\n"
"{\n"
"    background   : #40C0FF;\n"
"    border-style : outset;\n"
"    border-width : 2px;\n"
"    border-color : transparent;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::hover\n"
"{\n"
"    background   : #B0D5E8;\n"
"    border-color : blue;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::pressed\n"
"{\n"
"    background   : #0040C0;\n"
"    border-style : inset;\n"
"}\n"
"\n"
"QLabel[style=\"icon\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QFrame[style=\"title\"]\n"
"{\n"
"    margin-top     : 16px;\n"
"    margin-bottom  : 4px;\n"
"    margin-left    : 0px;\n"
"    margin-right   : 0px;\n"
"    border-radius  : 0px;\n"
"    border-bottom  : 2px solid silver;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    padding-top    : 2px;\n"
"    padding-bottom : 2px;\n"
"    padding-left   : -4px;\n"
"    padding-right  : 0px;\n"
"    color          : black;\n"
"    font-size      : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title\"], QFrame[style=\"title\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 4px;\n"
"    margin        : 2px;\n"
"    padding       : 2px;\n"
"    color         : black;\n"
"    font-size     : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title-embeded\"]\n"
"{\n"
"    background : #EEEEEE;\n"
"    color      : black;\n"
"    font-size  : 18px;\n"
"}\n"
"\n"
"\n"
"\n"
"\n"
"QLabel[style=\"helpbox\"]\n"
"{\n"
"    background    : transparent;\n"
"    color         : steelblue;\n"
"    padding       : 2px;\n"
"    border-radius : 4px;\n"
"}\n"
"\n"
"QLabel[style=\"subheading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    font-style: italic;\n"
"}\n"
"\n"
"QLabel[style=\"heading\"], QPushButton[style=\"heading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    border-bottom  : 1px solid #404040;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    color: #404040;\n"
"}\n"
"\n"
"\n"
"QTextEdit[style=\"console\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"    background : black;\n"
"    color      : white;\n"
"}\n"
"\n"
"QTextEdit[style=\"monospaced\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"}\n"
"\n"
"QPushButton[style=\"completed\"]\n"
"{\n"
"    background    : #00C080;\n"
"    border-color  : #00C080; \n"
"}\n"
"\n"
"QPushButton[style=\"cancel\"]\n"
"{\n"
"    background    : #C00000;\n"
"    color         : white;\n"
"    padding       : 8px;\n"
"    border-color  : white;\n"
"    border-width  : 1px;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QMdiArea[style=\"empty\"]\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"QLabel[style=\"warning\"]\n"
"{\n"
"    background       : #FFFFD0;\n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"    image            : url(\":/intermake/warning.svg\");\n"
"    image-position   : left;\n"
"    qproperty-indent : 24;\n"
"}\n"
"\n"
"QLabel[style=\"warning_no_icon\"]\n"
"{\n"
"    background       : #FFFF80;\n"
"    color            : #800000;          \n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"}\n"
"\n"
"QToolButton[style=\"dropdown\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/dropdown.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"refresh\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/refresh.svg);\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"combo\"]\n"
"{\n"
"    background: white;\n"
"}\n"
"\n"
"QFrame[style=\"contents\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px solid white;\n"
"    color: black;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"    border: 1px dotted #8080FF;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:pressed\n"
"{\n"
"    background: #B0D5E8;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]\n"
"{\n"
"    border: 1px solid transparent;\n"
"    background: transparent;\n"
"    qproperty-icon            : url(:/intermake/help.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:hover\n"
"{\n"
"    border: 1px outset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:pressed\n"
"{\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]\n"
"{\n"
"    background: transparent;\n"
"    border: none;\n"
"    color: blue;\n"
"    padding: 4px;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:pressed\n"
"{\n"
"    color: red;\n"
"    text-decoration: underline;\n"
"    border: 1px solid blue;\n"
"}\n"
"\n"
"QFrame[style=\"sidearea\"]\n"
"{\n"
"    background: gray;\n"
"}\n"
"\n"
"QToolButton[style=\"sidearea\"]\n"
"{\n"
"    background: gray;\n"
"    border: 1px solid gray;\n"
"    border-radius: 4px;\n"
"}\n"
"\n"
"QToolButton[style=\"sidearea\"]:hover\n"
"{\n"
"    background: qlineargradient(spread:pad, x1:1, y1:0, x2:1, y2:1, stop:0 rgba(195, 195, 195, 255), stop:0.0985222 rgba(255, 255, 255, 255), stop:1 rgba(135, 135, 135, 255));\n"
"    border: 1px outset gray;\n"
"    border-radius: 4px;\n"
"}\n"
"\n"
"QToolButton[style=\"sidearea\"]:pressed\n"
"{\n"
"    background: qlineargradient(spread:pad, x1:1, y1:0, x2:1, y2:1, stop:0 rgba(195, 195, 195, 255), stop:0.0985222 rgba(99, 99, 99, 255), stop:1 rgba(135, 135, 135, 255));\n"
"    border: 1px inset gray;\n"
"    border-radius: 4px;\n"
"}\n"
"\n"
"QAbstractButton[style=\"expander\"]:checked\n"
"{\n"
"    qproperty-icon : url(:/intermake/expanddown.svg);\n"
"}\n"
"\n"
"QAbstractButton[style=\"expander\"]:!checked\n"
"{\n"
"    qproperty-icon : url(:/intermake/expandup.svg);\n"
"}\n"
"")
        self.gridLayout = QtWidgets.QGridLayout(Dialog)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.SPLITTER_MAIN = QtWidgets.QSplitter(Dialog)
        self.SPLITTER_MAIN.setOrientation(QtCore.Qt.Horizontal)
        self.SPLITTER_MAIN.setHandleWidth(0)
        self.SPLITTER_MAIN.setChildrenCollapsible(False)
        self.SPLITTER_MAIN.setObjectName("SPLITTER_MAIN")
        self.PAN_MAIN_LEFT = QtWidgets.QWidget(self.SPLITTER_MAIN)
        self.PAN_MAIN_LEFT.setObjectName("PAN_MAIN_LEFT")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.PAN_MAIN_LEFT)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.PAGER_SET = QtWidgets.QStackedWidget(self.PAN_MAIN_LEFT)
        self.PAGER_SET.setObjectName("PAGER_SET")
        self.TWD_LEFTPage1 = QtWidgets.QWidget()
        self.TWD_LEFTPage1.setObjectName("TWD_LEFTPage1")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.TWD_LEFTPage1)
        self.verticalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_6.setSpacing(0)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.frame_3 = QtWidgets.QFrame(self.TWD_LEFTPage1)
        self.frame_3.setProperty("style", "sidearea")
        self.frame_3.setObjectName("frame_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.frame_3)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.BTN_SAVE = QtWidgets.QToolButton(self.frame_3)
        self.BTN_SAVE.setStyleSheet("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/bio42/save.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SAVE.setIcon(icon)
        self.BTN_SAVE.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_SAVE.setProperty("style", "sidearea")
        self.BTN_SAVE.setObjectName("BTN_SAVE")
        self.horizontalLayout_3.addWidget(self.BTN_SAVE)
        self.BTN_LOAD = QtWidgets.QToolButton(self.frame_3)
        self.BTN_LOAD.setStyleSheet("")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/bio42/browse.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_LOAD.setIcon(icon1)
        self.BTN_LOAD.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_LOAD.setProperty("style", "sidearea")
        self.BTN_LOAD.setObjectName("BTN_LOAD")
        self.horizontalLayout_3.addWidget(self.BTN_LOAD)
        self.BTN_SHOW_ADVANCED = QtWidgets.QToolButton(self.frame_3)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/bio42/next.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SHOW_ADVANCED.setIcon(icon2)
        self.BTN_SHOW_ADVANCED.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_SHOW_ADVANCED.setProperty("style", "sidearea")
        self.BTN_SHOW_ADVANCED.setObjectName("BTN_SHOW_ADVANCED")
        self.horizontalLayout_3.addWidget(self.BTN_SHOW_ADVANCED)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.verticalLayout_6.addWidget(self.frame_3)
        self.splitter_2 = QtWidgets.QSplitter(self.TWD_LEFTPage1)
        self.splitter_2.setOrientation(QtCore.Qt.Vertical)
        self.splitter_2.setObjectName("splitter_2")
        self.PAN_CYPHER = QtWidgets.QWidget(self.splitter_2)
        self.PAN_CYPHER.setObjectName("PAN_CYPHER")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.PAN_CYPHER)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label = QtWidgets.QLabel(self.PAN_CYPHER)
        self.label.setProperty("style", "heading")
        self.label.setObjectName("label")
        self.verticalLayout_3.addWidget(self.label)
        self.CMB_QUERY = QtWidgets.QComboBox(self.PAN_CYPHER)
        self.CMB_QUERY.setObjectName("CMB_QUERY")
        self.verticalLayout_3.addWidget(self.CMB_QUERY)
        self.label_2 = QtWidgets.QLabel(self.PAN_CYPHER)
        self.label_2.setProperty("style", "heading")
        self.label_2.setObjectName("label_2")
        self.verticalLayout_3.addWidget(self.label_2)
        self.TXT_CYPHER = QtWidgets.QPlainTextEdit(self.PAN_CYPHER)
        font = QtGui.QFont()
        font.setFamily("Courier New")
        self.TXT_CYPHER.setFont(font)
        self.TXT_CYPHER.setObjectName("TXT_CYPHER")
        self.verticalLayout_3.addWidget(self.TXT_CYPHER)
        self.FRA_PARAM_LOWER = QtWidgets.QWidget(self.splitter_2)
        self.FRA_PARAM_LOWER.setObjectName("FRA_PARAM_LOWER")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.FRA_PARAM_LOWER)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.label_3 = QtWidgets.QLabel(self.FRA_PARAM_LOWER)
        self.label_3.setProperty("style", "heading")
        self.label_3.setObjectName("label_3")
        self.verticalLayout_4.addWidget(self.label_3)
        self.scrollArea = QtWidgets.QScrollArea(self.FRA_PARAM_LOWER)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.FRA_PARAMETERS = QtWidgets.QWidget()
        self.FRA_PARAMETERS.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.FRA_PARAMETERS.setObjectName("FRA_PARAMETERS")
        self.LAY_PARAMETERS = QtWidgets.QGridLayout(self.FRA_PARAMETERS)
        self.LAY_PARAMETERS.setContentsMargins(0, 0, 0, 0)
        self.LAY_PARAMETERS.setObjectName("LAY_PARAMETERS")
        self.scrollArea.setWidget(self.FRA_PARAMETERS)
        self.verticalLayout_4.addWidget(self.scrollArea)
        self.BTN_EXECUTE = QtWidgets.QPushButton(self.FRA_PARAM_LOWER)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/bio42/run_query.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_EXECUTE.setIcon(icon3)
        self.BTN_EXECUTE.setIconSize(QtCore.QSize(12, 12))
        self.BTN_EXECUTE.setObjectName("BTN_EXECUTE")
        self.verticalLayout_4.addWidget(self.BTN_EXECUTE, 0, QtCore.Qt.AlignRight)
        self.verticalLayout_6.addWidget(self.splitter_2)
        self.PAGER_SET.addWidget(self.TWD_LEFTPage1)
        self.TWD_LEFTPage2 = QtWidgets.QWidget()
        self.TWD_LEFTPage2.setObjectName("TWD_LEFTPage2")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.TWD_LEFTPage2)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setSpacing(0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.frame_4 = QtWidgets.QFrame(self.TWD_LEFTPage2)
        self.frame_4.setProperty("style", "sidearea")
        self.frame_4.setObjectName("frame_4")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.frame_4)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.BTN_BACK_TO_QUERY = QtWidgets.QToolButton(self.frame_4)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/bio42/verify.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_BACK_TO_QUERY.setIcon(icon4)
        self.BTN_BACK_TO_QUERY.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_BACK_TO_QUERY.setProperty("style", "sidearea")
        self.BTN_BACK_TO_QUERY.setObjectName("BTN_BACK_TO_QUERY")
        self.horizontalLayout_4.addWidget(self.BTN_BACK_TO_QUERY)
        spacerItem1 = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout_7.addWidget(self.frame_4)
        self.widget_3 = QtWidgets.QWidget(self.TWD_LEFTPage2)
        self.widget_3.setObjectName("widget_3")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.widget_3)
        self.verticalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.label_9 = QtWidgets.QLabel(self.widget_3)
        self.label_9.setProperty("style", "heading")
        self.label_9.setObjectName("label_9")
        self.verticalLayout_9.addWidget(self.label_9)
        self.label_10 = QtWidgets.QLabel(self.widget_3)
        self.label_10.setWordWrap(True)
        self.label_10.setProperty("style", "helpbox")
        self.label_10.setObjectName("label_10")
        self.verticalLayout_9.addWidget(self.label_10)
        self.CMB_SOURCE = QtWidgets.QComboBox(self.widget_3)
        self.CMB_SOURCE.setObjectName("CMB_SOURCE")
        self.verticalLayout_9.addWidget(self.CMB_SOURCE)
        self.label_5 = QtWidgets.QLabel(self.widget_3)
        self.label_5.setProperty("style", "heading")
        self.label_5.setObjectName("label_5")
        self.verticalLayout_9.addWidget(self.label_5)
        self.label_7 = QtWidgets.QLabel(self.widget_3)
        self.label_7.setWordWrap(True)
        self.label_7.setProperty("style", "helpbox")
        self.label_7.setObjectName("label_7")
        self.verticalLayout_9.addWidget(self.label_7)
        self.CHK_ENABLE_BROWSER = QtWidgets.QCheckBox(self.widget_3)
        self.CHK_ENABLE_BROWSER.setObjectName("CHK_ENABLE_BROWSER")
        self.verticalLayout_9.addWidget(self.CHK_ENABLE_BROWSER)
        self.label_11 = QtWidgets.QLabel(self.widget_3)
        self.label_11.setWordWrap(True)
        self.label_11.setProperty("style", "helpbox")
        self.label_11.setObjectName("label_11")
        self.verticalLayout_9.addWidget(self.label_11)
        self.CHK_B42_SCRIPTS = QtWidgets.QCheckBox(self.widget_3)
        self.CHK_B42_SCRIPTS.setObjectName("CHK_B42_SCRIPTS")
        self.verticalLayout_9.addWidget(self.CHK_B42_SCRIPTS)
        self.BTN_CUSTOM_LIBRARIES = QtWidgets.QPushButton(self.widget_3)
        self.BTN_CUSTOM_LIBRARIES.setObjectName("BTN_CUSTOM_LIBRARIES")
        self.verticalLayout_9.addWidget(self.BTN_CUSTOM_LIBRARIES, 0, QtCore.Qt.AlignLeft)
        self.label_6 = QtWidgets.QLabel(self.widget_3)
        self.label_6.setProperty("style", "heading")
        self.label_6.setObjectName("label_6")
        self.verticalLayout_9.addWidget(self.label_6)
        self.label_8 = QtWidgets.QLabel(self.widget_3)
        self.label_8.setWordWrap(True)
        self.label_8.setProperty("style", "helpbox")
        self.label_8.setObjectName("label_8")
        self.verticalLayout_9.addWidget(self.label_8)
        self.CMB_DESTINATION = QtWidgets.QComboBox(self.widget_3)
        self.CMB_DESTINATION.setObjectName("CMB_DESTINATION")
        self.verticalLayout_9.addWidget(self.CMB_DESTINATION)
        spacerItem2 = QtWidgets.QSpacerItem(20, 569, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_9.addItem(spacerItem2)
        self.verticalLayout_7.addWidget(self.widget_3)
        self.PAGER_SET.addWidget(self.TWD_LEFTPage2)
        self.verticalLayout.addWidget(self.PAGER_SET)
        self.PAN_MAIN_RIGHT = QtWidgets.QWidget(self.SPLITTER_MAIN)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(4)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.PAN_MAIN_RIGHT.sizePolicy().hasHeightForWidth())
        self.PAN_MAIN_RIGHT.setSizePolicy(sizePolicy)
        self.PAN_MAIN_RIGHT.setObjectName("PAN_MAIN_RIGHT")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.PAN_MAIN_RIGHT)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.SPL_BROWSER_TREE = QtWidgets.QSplitter(self.PAN_MAIN_RIGHT)
        self.SPL_BROWSER_TREE.setOrientation(QtCore.Qt.Horizontal)
        self.SPL_BROWSER_TREE.setHandleWidth(0)
        self.SPL_BROWSER_TREE.setChildrenCollapsible(False)
        self.SPL_BROWSER_TREE.setObjectName("SPL_BROWSER_TREE")
        self.FRA_BROWSER_HOLDER_BASE = QtWidgets.QWidget(self.SPL_BROWSER_TREE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FRA_BROWSER_HOLDER_BASE.sizePolicy().hasHeightForWidth())
        self.FRA_BROWSER_HOLDER_BASE.setSizePolicy(sizePolicy)
        self.FRA_BROWSER_HOLDER_BASE.setStyleSheet("")
        self.FRA_BROWSER_HOLDER_BASE.setObjectName("FRA_BROWSER_HOLDER_BASE")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.FRA_BROWSER_HOLDER_BASE)
        self.verticalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.frame = QtWidgets.QFrame(self.FRA_BROWSER_HOLDER_BASE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setProperty("style", "sidearea")
        self.frame.setObjectName("frame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.frame)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.BTN_TREE = QtWidgets.QToolButton(self.frame)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/intermake/expandup.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_TREE.setIcon(icon5)
        self.BTN_TREE.setCheckable(True)
        self.BTN_TREE.setProperty("style", "sidearea")
        self.BTN_TREE.setObjectName("BTN_TREE")
        self.horizontalLayout.addWidget(self.BTN_TREE)
        self.BTN_SEND_TO = QtWidgets.QToolButton(self.frame)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/bio42/send.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SEND_TO.setIcon(icon6)
        self.BTN_SEND_TO.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_SEND_TO.setProperty("style", "sidearea")
        self.BTN_SEND_TO.setObjectName("BTN_SEND_TO")
        self.horizontalLayout.addWidget(self.BTN_SEND_TO)
        self.BTN_EXPORT_AS = QtWidgets.QToolButton(self.frame)
        self.BTN_EXPORT_AS.setStyleSheet("")
        self.BTN_EXPORT_AS.setIcon(icon)
        self.BTN_EXPORT_AS.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_EXPORT_AS.setProperty("style", "sidearea")
        self.BTN_EXPORT_AS.setObjectName("BTN_EXPORT_AS")
        self.horizontalLayout.addWidget(self.BTN_EXPORT_AS)
        self.BTN_SYSTEM_BROWSER = QtWidgets.QToolButton(self.frame)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/bio42/browser.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.BTN_SYSTEM_BROWSER.setIcon(icon7)
        self.BTN_SYSTEM_BROWSER.setToolButtonStyle(QtCore.Qt.ToolButtonTextBesideIcon)
        self.BTN_SYSTEM_BROWSER.setProperty("style", "sidearea")
        self.BTN_SYSTEM_BROWSER.setObjectName("BTN_SYSTEM_BROWSER")
        self.horizontalLayout.addWidget(self.BTN_SYSTEM_BROWSER)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.verticalLayout_8.addWidget(self.frame)
        self.FRA_BROWSER_HOLDER = QtWidgets.QWidget(self.FRA_BROWSER_HOLDER_BASE)
        self.FRA_BROWSER_HOLDER.setStyleSheet("background: cornflowerblue;")
        self.FRA_BROWSER_HOLDER.setObjectName("FRA_BROWSER_HOLDER")
        self.GRID_BROWSER_HOLDER = QtWidgets.QGridLayout(self.FRA_BROWSER_HOLDER)
        self.GRID_BROWSER_HOLDER.setContentsMargins(0, 0, 0, 0)
        self.GRID_BROWSER_HOLDER.setSpacing(0)
        self.GRID_BROWSER_HOLDER.setObjectName("GRID_BROWSER_HOLDER")
        self.verticalLayout_8.addWidget(self.FRA_BROWSER_HOLDER)
        self.FRA_TREE_HOLDER_BASE = QtWidgets.QWidget(self.SPL_BROWSER_TREE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FRA_TREE_HOLDER_BASE.sizePolicy().hasHeightForWidth())
        self.FRA_TREE_HOLDER_BASE.setSizePolicy(sizePolicy)
        self.FRA_TREE_HOLDER_BASE.setStyleSheet("")
        self.FRA_TREE_HOLDER_BASE.setObjectName("FRA_TREE_HOLDER_BASE")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.FRA_TREE_HOLDER_BASE)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setSpacing(0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.FRA_TREE_BAR = QtWidgets.QFrame(self.FRA_TREE_HOLDER_BASE)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.FRA_TREE_BAR.sizePolicy().hasHeightForWidth())
        self.FRA_TREE_BAR.setSizePolicy(sizePolicy)
        self.FRA_TREE_BAR.setProperty("style", "sidearea")
        self.FRA_TREE_BAR.setObjectName("FRA_TREE_BAR")
        self.LAY_TREE_BAR = QtWidgets.QHBoxLayout(self.FRA_TREE_BAR)
        self.LAY_TREE_BAR.setContentsMargins(0, 0, 0, 0)
        self.LAY_TREE_BAR.setSpacing(0)
        self.LAY_TREE_BAR.setObjectName("LAY_TREE_BAR")
        self.BTN_LOCAL_BROWSER = QtWidgets.QToolButton(self.FRA_TREE_BAR)
        self.BTN_LOCAL_BROWSER.setIcon(icon5)
        self.BTN_LOCAL_BROWSER.setCheckable(True)
        self.BTN_LOCAL_BROWSER.setProperty("style", "sidearea")
        self.BTN_LOCAL_BROWSER.setObjectName("BTN_LOCAL_BROWSER")
        self.LAY_TREE_BAR.addWidget(self.BTN_LOCAL_BROWSER)
        self.verticalLayout_5.addWidget(self.FRA_TREE_BAR)
        self.FRA_TREE_HOLDER = QtWidgets.QWidget(self.FRA_TREE_HOLDER_BASE)
        self.FRA_TREE_HOLDER.setStyleSheet("background: violet;")
        self.FRA_TREE_HOLDER.setObjectName("FRA_TREE_HOLDER")
        self.verticalLayout_5.addWidget(self.FRA_TREE_HOLDER)
        self.verticalLayout_2.addWidget(self.SPL_BROWSER_TREE)
        self.gridLayout.addWidget(self.SPLITTER_MAIN, 0, 0, 1, 1)

        self.retranslateUi(Dialog)
        self.PAGER_SET.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.BTN_SAVE.setText(_translate("Dialog", "Save"))
        self.BTN_LOAD.setText(_translate("Dialog", "Load"))
        self.BTN_SHOW_ADVANCED.setText(_translate("Dialog", "Advanced"))
        self.label.setText(_translate("Dialog", "Query"))
        self.label_2.setText(_translate("Dialog", "Cypher"))
        self.label_3.setText(_translate("Dialog", "Parameters"))
        self.BTN_EXECUTE.setText(_translate("Dialog", "Execute"))
        self.BTN_BACK_TO_QUERY.setText(_translate("Dialog", "Accept"))
        self.label_9.setText(_translate("Dialog", "Data source"))
        self.label_10.setText(_translate("Dialog", "The data has to come from somewhere!"))
        self.label_5.setText(_translate("Dialog", "Enable"))
        self.label_7.setText(_translate("Dialog", "Turn the inbuilt browser off if it\'s causing problems or you\'d like to use your own browser."))
        self.CHK_ENABLE_BROWSER.setText(_translate("Dialog", "Enable browser (requires restart)"))
        self.label_11.setText(_translate("Dialog", "Add or remove script libraries. Note that loading extra libraries can take time."))
        self.CHK_B42_SCRIPTS.setText(_translate("Dialog", "Enable bio42_scripts"))
        self.BTN_CUSTOM_LIBRARIES.setText(_translate("Dialog", "Manage custom libraries"))
        self.label_6.setText(_translate("Dialog", "Send output to"))
        self.label_8.setText(_translate("Dialog", "This interface directs the output at the GUI by default, but you can send it somewhere else instead."))
        self.BTN_SEND_TO.setText(_translate("Dialog", "Send"))
        self.BTN_EXPORT_AS.setText(_translate("Dialog", "Export"))
        self.BTN_SYSTEM_BROWSER.setText(_translate("Dialog", "System"))





from distutils.core import setup

def __rld():
    try:
        import os.path
        with open(os.path.join(os.path.dirname(__file__), "readme.rst")) as file:
            return file.read()
    except Exception as ex:
        return "(could not load readme: {})".format(ex)

setup( name = "bio42",
       url = "https://bitbucket.org/mjr129/bio42",
       version = "0.0.0.27",
       description = "Bio42. Analyser and database manager and for large biological networks stored in Neo4j.",
       long_description = __rld(),
       author = "Martin Rusilowicz",
       license = "https://www.gnu.org/licenses/agpl-3.0.html",
       python_requires = ">=3.6",
       
       entry_points = \
           {
               "console_scripts": ["bio42 = bio42.__main__:main"]
           },
       
       packages = \
           [
               "bio42",
               "bio42.application",
               "bio42.commands",
               "bio42.commands.downloads",
               "bio42.commands.parsers",
               "bio42_gui",
               "bio42_gui.controller",
               "bio42_gui.controls",
               "bio42_gui.forms",
               "bio42_gui.forms.designer",
               "bio42_gui.forms.designer.resources",
               "bio42_scripts",
               "bio42_tests"
           ],

       install_requires = \
           [
               "uniprot",
               "typing",
               "py-flags",
               "colorama",
               "editorium",
               "stringcoercion",
               "keyring",
               "progressivecsv",
               "biopython",
               "intermake",
               "mhelper",
               "PyQt5",
               "neocommand",
               'mgraph'
           ],
       
       classifiers = \
           [
               "Development Status :: 3 - Alpha",
        
               "Environment :: Console",
               "Environment :: Win32 (MS Windows)",
               "Environment :: X11 Applications :: Qt",
               "Environment :: MacOS X",
               "Operating System :: OS Independent",
               "Operating System :: Microsoft :: Windows",
               "Operating System :: MacOS",
               "Operating System :: POSIX :: Linux",
        
               "Intended Audience :: Science/Research",
               "Topic :: Database",
               "Topic :: Scientific/Engineering",
               "Topic :: Scientific/Engineering :: Bio-Informatics",
               "Topic :: Utilities",
               "Topic :: Multimedia :: Graphics :: Presentation",
        
               "License :: OSI Approved :: GNU Affero General Public License v3",
               "License :: OSI Approved :: GNU Affero General Public License v3 or later (AGPLv3+)",
        
               "Natural Language :: English",
               "Programming Language :: Python :: 3.6",
               "Programming Language :: Python :: 3",
               "Programming Language :: Python :: 3 :: Only"
           ]
       )



from typing import Optional

import warnings
import intermake
import neocommand
import os
import os.path
import zipfile

from bio42.application import app
from bio42.commands.downloads import _common

@app.command( folder = "import" )
def download_taxonomy( destination: Optional[neocommand.Destination], extract: bool = True, refresh: bool = False, clean: bool = False, url: str = "" ) -> None:
    """
    Downloads and optionally imports the NCBI taxonomy database.
    
    :param refresh:     Downloads and extracts the ZIP file into a database file, even either
                        already exist on disk.
    :param destination:        Endpoint to import into.
                        `None` = Just download and extract, don't import 
    :param extract:     ZIPs are extracted into databases.
                        Unsetting this parameter prevents that.
                        This parameter is enforced if an `endpoint` is specified.
    :param clean:       ZIP files are deleted after extraction and database files are deleted
                        after importation.
                        Unsetting this parameter prevents that.
    :param url:         Specifies the location of the NCBI taxonomy database dump to use.
                        If this is left blank, a default location is assumed:
                            
                            ftp://ftp.ncbi.nlm.nih.gov/pub/taxonomy/new_taxdump/new_taxdump.zip
                            
                        The ZIP will be downloaded, extracted and imported.
                        Please make sure that you trust the source.
    """
    url = url or "ftp://ftp.ncbi.nlm.nih.gov/pub/taxonomy/new_taxdump/new_taxdump.zip"
    
    dir = intermake.Controller.ACTIVE.app.local_data.local_folder( "downloads", "taxonomy" )
    zip_fn = os.path.join( dir, "new_taxdump.zip" )
    tax_fn = os.path.join( dir, "nodes.dmp" )
    nam_fn = os.path.join( dir, "names.dmp" )
    
    zip_exists = os.path.isfile( zip_fn )
    tax_exists = os.path.isfile( tax_fn )
    nam_exists = os.path.isfile( nam_fn )
    dat_exists = tax_exists and nam_exists
    
    is_my_zip = False
    download = True
    my_extraction = ()
    
    if not extract and destination is not None:
        warnings.warn( "Setting `extract` to `True` because an `endpoint` was specified." )
        extract = True
    
    #
    # If there is only half a database, remove it
    #
    if nam_exists and not tax_exists:
        os.remove( nam_fn )
        dat_exists = False
        warnings.warn( "A partial database existed, this has been now deleted:\n * {}".format( nam_fn ) )
    elif tax_exists and not nam_exists:
        os.remove( tax_fn )
        dat_exists = False
        warnings.warn( "A partial database existed, this has been now deleted:\n * {}".format( tax_fn ) )
    
    #
    # If a ZIP file already exists, remove it
    #
    if zip_exists:
        if refresh:
            os.remove( zip_fn )
            warnings.warn( "The existing ZIP has been deleted: {}".format( zip_fn ) )
        else:
            print( "Not downloading anything because the ZIP file already exists:\n * {}".format( zip_fn ) )
            download = False
    
    #
    # If a database already exists, remove it
    #
    if dat_exists:
        if refresh:
            os.remove( tax_fn )
            os.remove( nam_fn )
            warnings.warn( "The existing database has been deleted:\n * {}\n * {}".format( tax_fn, nam_fn ) )
        else:
            print( "Not downloading anything because the database files already exist:\n * {}\n * {}".format( tax_fn, nam_fn ) )
            download = False
            extract = False
    
    #
    # Download the data
    #
    if download:
        _common.download_file( url, zip_fn )
        is_my_zip = True
    
    #
    # Extract the data?
    #
    if extract:
        with intermake.pr.pr_action( "Extracting" ):
            zip = zipfile.ZipFile( zip_fn, 'r' )
            zip.extract( "nodes.dmp" )
            zip.extract( "names.dmp" )
            my_extraction = zip.namelist() if clean else ()
            zip.close()
        
        #
        # Remove the ZIP
        #
        if clean and is_my_zip:
            with intermake.pr.pr_action( "Deleting downloaded zip" ):
                os.remove( zip_fn )
    
    #
    # Import the database
    #
    if destination is not None:
        import bio42
        bio42.import_taxonomy( destination, tax_fn, nam_fn )
        
        #
        # Clean the extracted files
        #
        if clean and my_extraction:
            for name in intermake.pr.pr_iterate( my_extraction, title = "Deleting extracted files" ):
                name = os.path.join( dir, name )
                os.remove( name )





import bio42 as b4
import time

from bio42_tests._helpers import Config, log


def main():
    """
    This is our test program's entry point.
    """
    # Read our configuration from the command line
    log( "Read our configuration from the command line" )
    config = Config()
    
    # Open a connection to our database
    log( "Open a connection to our database" )
    database  = b4.open_database( name      = "db_endpoint",
                                  driver    = config.db_driver,
                                  host      = config.db_host,
                                  user      = config.db_user,
                                  password  = config.db_password,
                                  directory = config.db_directory,
                                  os        = config.db_operating_system,
                                  port      = config.db_port )
    
    # Create our destination "parcels"
    base_parcel      = b4.open_parcel( name = "base_parcel"         )
    taxa_parcel      = b4.open_parcel( name = "taxa_parcel"         )
    ontology_parcel  = b4.open_parcel( name = "ontology_parcel"     )
    sequences_parcel = b4.open_parcel( name = "sequences_parcel"    )
    blast_parcel     = b4.open_parcel( name = "blast_parcel"        )
    anno_parcel      = b4.open_parcel( name = "anno_parcel"         )
    fam_parcel       = b4.open_parcel( name = "fam_parcel"          )
    coin_parcel      = b4.open_parcel( name = "coin_parcel"         )
    
    # Download and import taxa
    log( "Download and import taxa" )
    b4.download_taxonomy( destination   = taxa_parcel,
                          refresh       = config.refresh_downloads,
                          clean         = config.remove_downloads )
    
    # Download and import GO terms
    log( "Download and import GO terms" )
    b4.download_ontology( destination   = ontology_parcel,
                          refresh       = config.refresh_downloads,
                          clean         = config.remove_downloads )
    
    # Import our sequence data
    log( "Import our sequence data" )
    b4.import_sequences( file            = config.genbank_file,
                         destination     = sequences_parcel,
                         create          = b4.ESequenceFlags.ALL,
                         user_edges      = config.genbank_user_edges,
                         taxonomy_source = taxa_parcel )
    
    # Import our BLAST data
    log( "Import our BLAST data" )
    b4.import_blast( file_name      = config.blast_file,
                     destination    = blast_parcel,
                     deep_query     = True )
    
    # Import our annotations
    log( "Import our annotations" )
    b4.import_annotations( file_name    = config.annotations_file,
                           destination  = anno_parcel )
    
    # Import our gene families
    log( "Import our gene families" )
    b4.import_csv( file_name        = config.coincidence_family_file,
                   destination      = coin_parcel,
                   mapping          = config.coincidence_family_map )
    
    # Import our coincidence network
    log( "Import our coincidence network" )
    b4.import_csv( file_name        = config.coincidence_edge_file,
                   destination      = fam_parcel,
                   mapping          = config.coincidence_edge_map )
    
    # Move our data into the database!
    # Note that we use a variety of methods for testing, not because it's efficient!
    
    # Create a 'base_parcel' that contains most of the information
    log( "Move taxa_parcel to base_parcel" )
    b4.transfer( origin             = taxa_parcel,
                 destination        = base_parcel )
    
    log( "Move ontology_parcel to base_parcel" )
    b4.transfer( origin             = ontology_parcel,
                 destination        = base_parcel )
    
    log( "Move sequences_parcel to base_parcel" )
    b4.transfer( origin             = sequences_parcel,
                 destination        = base_parcel )
    
    log( "Move blast_parcel to base_parcel" )
    b4.transfer( origin             = blast_parcel,
                 destination        = base_parcel )
    
    # Create a new database from our 'base_parcel' and switch Neo4j to using it
    log( "Move base_parcel to database" )
    b4.transfer( origin             = base_parcel,
                 destination        = database,
                 method             = b4.EParcelMethod.CREATE )
    
    log( "Set database as active" )
    b4.set_database( server         = database,
                     database       = base_parcel.name )
    
    log( "Restart database server" )
    b4.control_server( server       = database,
                       command      = b4.ENeo4jCommand.RESTART )
    
    log( "Wait for server to restart" )
    while not b4.test_connection( server = database ).is_running:
        print( "Waiting for Neo4j to restart." )
        time.sleep( 2 )
    
    # Add our other information using the remaining methods we haven't yet tested
    log( "Move anno_parcel to database" )
    b4.transfer( origin         = anno_parcel,
                 destination    = database,
                 method         = b4.EParcelMethod.DIRECT )
    
    log( "Move fam_parcel to database" )
    b4.transfer( origin         = fam_parcel,
                 destination    = database,
                 method         = b4.EParcelMethod.ADD )
    
    log( "Move coin_parcel to database" )
    b4.transfer( origin         = coin_parcel,
                 destination    = database,
                 method         = b4.EParcelMethod.IMPORT )
    
    # Clean up 
    for parcel in (base_parcel, taxa_parcel, ontology_parcel, sequences_parcel,
                   blast_parcel, anno_parcel, fam_parcel, coin_parcel):
        log( "Delete {} from disk".format( parcel.name ) )
        b4.close_endpoint( endpoint = parcel, 
                           delete   = True )
    
    log( "Close the database connection" )
    b4.close_endpoint( database )


if __name__ == "__main__":
    main()



import datetime
import re
import intermake
import neocommand
import uuid

from collections import defaultdict
from typing import Dict, Iterator, List, Optional, Tuple, Union, cast
from mhelper import EFileMode, isFilename, SwitchError, array_helper, file_helper, string_helper, MFlags, isOptional
from Bio import SeqIO
from Bio.Alphabet import Alphabet
from Bio.SeqFeature import CompoundLocation, FeatureLocation, Reference, SeqFeature
from Bio.SeqRecord import SeqRecord

from bio42 import schema
from bio42.application import app
from bio42.commands.parsers import parser_taxonomy


class ESequenceFlags( MFlags ):
    """
    :cvar SOURCES:           Source edges.
                                `True`  - an edge to the 'Source' node is included, denoting the origin of the data (i.e. the file path).
                                          This may be useful in limited circumstances when combining multiple datasets into the same
                                          database, but incurs an additional memory overhead of one additional edge per sequence.
                                `False` - `Source` nodes are not included.
    :cvar FASTAS:   Record sequences.
                              * `True` - full sequence data is added to the created Record nodes.
    :cvar FEATURE_FASTAS:  Feature sequences.
                              * `True` - full sequence data is added to the created Feature nodes.
    :cvar FEATURES:          Create nodes for features.
    :cvar REFERENCES:        Create nodes for references.
    :cvar ANNOTATIONS:       Create properties for record annotations. 
    :cvar QUALIFIERS:        Create properties for feature annotations ("qualifiers").

    """
    SOURCES = 1
    FASTAS = 2
    FEATURE_FASTAS = 4
    REFERENCES = 8
    FEATURES = 16
    QUALIFIERS = 32
    ANNOTATIONS = 64


@app.command( folder = "import" )
def import_sequences( file: isFilename[EFileMode.READ],
                      destination: neocommand.Destination,
                      create: ESequenceFlags = ESequenceFlags.NONE,
                      code: str = "",
                      id_parts: Optional[List[str]] = None,
                      user_edges: Optional[List[str]] = None,
                      taxonomy_file: isOptional[isFilename[EFileMode.READ]] = None,
                      taxonomy_source: Optional[neocommand.Origin] = None,
                      biopython_extraction: bool = False,
                      no_count: bool = False, ):
    # noinspection SpellCheckingInspection
    """
        Imports genes and sequences from a variety of formats.
        
        .. note::
        
            Requires BioPython.
    
        .. note::
        
            Labels, entities and properties are dynamic and dependent on the arguments passed and information found in 
            the source file.
        
        :param no_count:                  Disables counting.
                                          When set, skips the record counting step (this step is only used to estimate
                                          the processing time and show the progress bar).
                                          
        :param destination:                  Endpoint.
                                          Where to send the data to.
                                          
        :param file:                      The file to read.
                                          This can be in any of the formats accepted by the version of BioPython you
                                          have installed. At the time of writing this includes the following types:
                                              ABIF, ACE, EMBL, FASTA, FASTQ, FASTQ, FASTQ, FASTQ, Genbank,
                                              IntelliGenetics, IMGT, Protein, Bio, PHRED, NBRF, XML, SFF, SFF, XML,
                                              TSV, Quality, TXT.
                                              
        :param code:                      The type of file.
                                          This should designate the format of the `file`.
                                          This may be left blank, in which case the type is automatically determined
                                          from the file extension. 
                                          * `Empty`  = "default" 
                                           
        :param biopython_extraction:      Extraction method.
                                          * `True`  = "biopython" - Uses BioPython's extract feature, which is great
                                                                    but can be a bit slow.
                                          * `False` = "custom"    - uses a custom quick method (faster but less reliable).
                                          
        :param user_edges:                Edges to create.
                                          ¡Please see the help topic: `user_edges` for details!
                                          
        :param taxonomy_file:             Taxonomy-names file.
                                          Required if taxonomy nodes are specified in the `user_edges` argument,
                                          otherwise, this parameter is unused.
                                          Mutually exclusive with `taxonomy_database`.
                                          
        :param taxonomy_source:         Taxonomy-names source.
                                          Required if taxonomy nodes are specified in the `user_edges` argument,
                                          otherwise, this parameter is unused.
                                          Mutually exclusive with `taxonomy_file`.
                                          
        :param id_parts:                  How to determine the gene accession from the names in the file.
                                          See the help topic: `id_parts`.
                                          If no argument is specified, the entirety of the name as the accession.
                                          
        :param create:                    A set of flags which specifies the elements to create.
        """
    with destination.open_writer() as writer:
        __Process( file = file,
                   code = code,
                   writer = writer,
                   create = create,
                   id_parts = id_parts,
                   user_edges = user_edges,
                   taxonomy_file = taxonomy_file,
                   taxonomy_database = taxonomy_source,
                   biopython_extraction = biopython_extraction,
                   no_count = no_count )


# noinspection SpellCheckingInspection
class __Process:
    # noinspection SpellCheckingInspection
    def __init__( self,
                  *,
                  file: isFilename[EFileMode.READ],
                  code: str,
                  writer: neocommand.Writer,
                  create: ESequenceFlags,
                  id_parts: Optional[List[str]],
                  user_edges: Optional[List[str]],
                  taxonomy_file: isOptional[isFilename[EFileMode.READ]],
                  taxonomy_database: Optional[neocommand.Origin],
                  biopython_extraction: bool,
                  no_count: bool = False ):
        self.include_record_sequence = create.FASTAS
        self.include_feature_sequence = create.FEATURE_FASTAS
        self.include_references = create.REFERENCES
        self.include_features = create.FEATURES
        self.include_annotations = create.ANNOTATIONS
        self.include_qualifiers = create.QUALIFIERS
        
        if taxonomy_file:
            self.taxonomy_names_list = parser_taxonomy._read_scientific_names( taxonomy_file )
        elif taxonomy_database:
            self.taxonomy_names_list = _read_scientific_names_db( taxonomy_database )
        else:
            self.taxonomy_names_list = None
        self.id_parts = id_parts
        self.id_part_has_uid = neocommand.PRIMARY_KEY in id_parts if id_parts else False
        self.endpoint = neocommand.CounterWriter( writer )
        self.create_edges = self.__parse_user_edges_argument( user_edges )
        
        # Determine file type
        handler: IsParserFilter = None
        ext = file_helper.get_extension( file ).lower()
        
        if code:
            handler = IsParserFilter( code, code, "." + code, code, None )
        else:
            for x in _SEQUENCE_EXT:
                if x.extension == ext:
                    handler = x
                    break
            
            if handler is None:
                raise ValueError( "Did not understand extension. Please rename the file or provide a `code` parameter." )
        
        # Create "Source" node
        if create.SOURCES:
            self.source_uid = str( uuid.uuid4() )
            writer.create_node( label = schema.Source,
                                uid = self.source_uid,
                                properties = { "file_name"  : str( file ),
                                               "name"       : file_helper.get_filename( file ),
                                               "import_date": str( datetime.datetime.now() ) } )
        else:
            self.source_uid = None
        
        if handler.detect_records and not no_count:
            rx = re.compile( handler.detect_records )
            num_records = 0
            
            with intermake.pr.pr_action( "Counting records" ) as action:
                with open( file, "r" ) as file_in:
                    for line in file_in:
                        if rx.match( line ):
                            num_records += 1
                            action.increment()
        else:
            num_records = -1
        
        title = "Iterating {}".format( file_helper.get_filename( file ) )
        
        with intermake.pr.pr_action( title,
                                     count = num_records,
                                     text = lambda _: "{} nodes, {} edges".format( self.endpoint.num_nodes, self.endpoint.num_edges ) ) as action:
            self.action = action
            with open( file, "r" ) as file_in:
                for record in SeqIO.parse( file_in, handler.code ):
                    self.__process_line( record, biopython_extraction )
                    action.increment()
    
    
    @staticmethod
    def __parse_user_edges_argument( create_edges ):
        create_edges_list = []
        if create_edges:
            for x in create_edges:
                xx = x.split( "=" )
                if len( xx ) != 2:
                    raise ValueError( "The `create_edges` parameter expects key=value pairs: «{}» is invalid.".format( x ) )
                
                create_edges_list.append( xx )
        
        return create_edges_list
    
    
    def __read_id( self, id: str, props ) -> None:
        """
        FASTA contains other garbage that isn't in the GB, so to stay compatible we remove it
        This only works for GB fasta files and similar (i.e. where the true ID is the last element of the provided ID)
        """
        elements = id.split( "|" )
        
        if self.id_parts:
            if len( elements ) != len( self.id_parts ):
                raise ValueError( "The ID «{}» is not compatible with the ID format specified: «{}». Maybe you meant to specify a different format?".format( id, "|".join( self.id_parts ) ) )
            
            for index, property in enumerate( self.id_parts ):
                if property:
                    props[self._make_property_name( property, "" )] = elements[index]
        
        if not self.id_part_has_uid:
            assert neocommand.PRIMARY_KEY not in props
            props[neocommand.PRIMARY_KEY] = id.strip()
        
        assert neocommand.PRIMARY_KEY in props, "Internal error. ID parsed: «{}». No «{}» in properties: {}".format( id, neocommand.PRIMARY_KEY, props )
        assert props[neocommand.PRIMARY_KEY], "Internal error. ID parsed: «{}». Invalid «{}» in properties: {}".format( id, neocommand.PRIMARY_KEY, props )
    
    
    def __process_line( self, record: SeqRecord, true_extract: bool ) -> None:
        #
        # Record node
        #
        annotation_references, props, uid = self.__mk_record_node( record )
        
        #
        # Features
        #
        if self.include_features:
            for f in record.features:  # type:SeqFeature
                self.__mk_feature( f, record, uid, true_extract )
                self.action.still_alive()
        
        #
        # References
        #
        if self.include_references:
            for key, value in annotation_references.items():
                self.__mk_reference_node( key, uid, value )
                self.action.still_alive()
        
        #
        # Source edge
        if self.source_uid is not None:
            self.__mk_source_edge( uid )
        
        # 
        # User edges
        #
        if self.create_edges:
            for property, label in self.create_edges:
                self.__mk_user_edge( label, property, props, uid )
                self.action.still_alive()
    
    
    def __mk_record_node( self, record: SeqRecord ):
        """
        Creates a `NcNode` from a `SeqRecord`.
        """
        #
        # Truncate superfluous information
        #
        
        # - ignore record name if it is the same as the ID
        record_name = record.name
        
        if record_name == record.id:
            record_name = None
        
        # - truncate the part of the description that is the same as the ID
        description = record.description
        if description.startswith( record.id ):
            description = description[len( cast( str, record.id ) ):].lstrip()
        
        # - simplify the alphabet name
        alphabet_name = self._alphabet_shortcode( record.seq.alphabet )
        
        #
        # Create the property dictionary
        #
        props = { }
        props["source_id"] = record.id
        props["sequence_alphabet"] = alphabet_name
        if self.include_record_sequence:
            props["sequence"] = str( record.seq )
        if record_name:
            props["name"] = record_name
        if len( record.letter_annotations ):
            props["letter_annotations_count"] = len( record.letter_annotations )
        if len( record.dbxrefs ):
            # noinspection SpellCheckingInspection
            props["dbxrefs"] = record.dbxrefs
        if len( record.seq ):
            props["sequence_length"] = len( record.seq )
        if len( record.features ):
            props["features_count"] = len( record.features )
        if len( record.annotations ):
            props["annotations_count"] = len( record.annotations )
        if description:
            props["description"] = description
        self.__read_id( cast( str, record.id ), props )
        annotation_references = { }
        
        #
        # Dictionary annotations get expanded
        #
        annotations = { }
        
        if self.include_annotations:
            for key, value in record.annotations.items():
                def recursive_add( target_1, key_1, value_1 ):
                    if type( value_1 ) in [dict, defaultdict]:
                        for key_2, value_2 in value_1.items():
                            recursive_add( target_1, key_1 + "_" + key_2, value_2 )
                    else:
                        target_1[key_1] = value_1
                
                
                recursive_add( annotations, key, value )
            
            #
            # Convert annotations to properties with a leading "_"
            #
            for key, value in annotations.items():
                if not value:
                    # Don't add empty annotations
                    continue
                if type( value ) in neocommand.NeoType._BY_TYPE:
                    # Add all standard typed annotations
                    props[self._make_property_name( key )] = value  # if this is the wrong type it will get caught later
                elif (type( value ) == list) and (array_helper.list_type( value ) in neocommand.NeoType._BY_TYPE):
                    # Add lists of standard typed annotations
                    props[self._make_property_name( key )] = value
                elif type( value ) == Reference:
                    # Add references in their own special set
                    annotation_references[key] = value
                elif (type( value ) == list) and (array_helper.list_type( value ) == Reference):
                    # Add lists of references
                    for i, vv in enumerate( value ):
                        if type( vv ) == Reference:
                            annotation_references[key + "_" + str( i )] = vv
                else:
                    raise NotImplementedError( "InstanceHandler not implemented for annotation type. Regarding annotation «{0}» of value «{1}» and type «{2}» within sequence «{3}»".format( key, value, type( value ).__name__, record.id ) )
        
        #
        # Write
        #
        uid = props[neocommand.PRIMARY_KEY]
        del props[neocommand.PRIMARY_KEY]
        self.endpoint.create_node( label = schema.Sequence,
                                   uid = uid,
                                   properties = props )
        
        return annotation_references, props, uid
    
    
    def __mk_user_edge( self, label: str, property: str, record_props: Dict[str, Optional[object]], uid: str ):
        value = record_props.get( property )
        
        if value:
            if label == "Taxon" and self.taxonomy_names_list is not None:
                taxon_uid = self.taxonomy_names_list.get( value )
                
                if taxon_uid is None:
                    raise ValueError( "Cannot get the UID of the taxon named «{}» in the sequence with UID = «{}».".format( value, uid ) )
                
                value = taxon_uid
            
            self.endpoint.create_edge( label = schema.TaxonContainsSequence,
                                       start_uid = value,
                                       end_uid = uid,
                                       properties = { } )
    
    
    def __mk_source_edge( self, record_uid: str ):
        self.endpoint.create_edge( label = schema.SourceContainsSequence,
                                   start_uid = self.source_uid,
                                   end_uid = record_uid,
                                   properties = { } )
    
    
    def __mk_reference_node( self, reason: str, record_uid: str, reference: Reference ):
        reference_name = self._get_unique_id( reference )
        location = _LocationExtract( reference.location )
        self.endpoint.create_node( label = schema.Reference,
                                   uid = reference_name,
                                   properties = {
                                       "authors"            : reference.authors,
                                       "comment"            : reference.comment,
                                       "consrtm"            : reference.consrtm,  # I presume this is "consortium", but I haven't translated it because I cannot find any documentation to that effect
                                       "journal"            : reference.journal,
                                       "location_start"     : location.start,
                                       "location_end"       : location.end,
                                       "location_start_type": location.start_type,
                                       "location_end_type"  : location.end_type,
                                       "title"              : reference.title,
                                       "medline_id"         : reference.medline_id,
                                       "pubmed_id"          : reference.pubmed_id
                                   } )
        
        self.endpoint.create_edge( label = schema.SequenceReferencesReference,
                                   start_uid = record_uid,
                                   end_uid = reference_name,
                                   properties = { "reason": reason } )
    
    
    class MSubset:
        def __init__( self, record: SeqRecord, location: "_LocationExtract" ):
            self.record = record
            self.location = location
        
        
        @property
        def seq( self ) -> str:
            return self.record.seq[self.location.start:self.location.end]  # TODO: Check this, should it be inclusive?
        
        
        @property
        def features( self ) -> Iterator[SeqFeature]:
            for feature in self.record.features:
                location = _LocationExtract( feature.location )
                
                if self.location.start <= location.end and location.start <= self.location.end:
                    yield feature
    
    
    def __mk_feature( self, feature: SeqFeature, record: SeqRecord, record_uid: str, true_extract: bool ):
        """
        Converts a `SeqFeature` to a `NcNode`.
        """
        location = _LocationExtract( feature.location )
        
        if true_extract:
            record_subset = feature.extract( record )  # type: SeqRecord
        else:
            record_subset = self.MSubset( record, location )
        
        props = { }
        
        for key, value in feature.qualifiers.items():
            if key == "db_xref":
                for db_xref in value:
                    db, _ = db_xref.split( ":", 1 )
                    props["db_xref" + self._make_property_name( db )] = db_xref
            else:
                if self.include_qualifiers:
                    props[self._make_property_name( key )] = array_helper.decomplex( value )
        
        props["type"] = feature.type
        props["location_start"] = location.start
        props["location_end"] = location.end
        props["location_start_type"] = location.start_type
        props["location_end_type"] = location.end_type
        
        # Include sequence data
        if self.include_feature_sequence:
            props["sequence"] = record_subset.seq
        
        # The `translation` is annoying, get rid
        if "_translation" in props:
            del props["_translation"]
        
        feature_label, feature_uid = self.__get_feature_label_and_uid( feature, record_uid, location )
        
        props["feature_type"] = feature_label
        
        self.endpoint.create_node( label = schema.Feature,
                                   uid = feature_uid,
                                   properties = props )
        
        self.endpoint.create_edge( label = schema.SequenceContainsFeature,
                                   start_uid = record_uid,
                                   end_uid = feature_uid,
                                   properties = { } )
        
        for f2 in record_subset.features:
            f2_label, f2_uid = self.__get_feature_label_and_uid( f2, record_uid )
            
            f_key = feature_label + "|" + feature_uid
            f2_key = f2_label + "|" + f2_uid
            
            if f2_key >= f_key:
                continue  # Only create 1 edge
            
            self.endpoint.create_edge( label = schema.FeatureOverlapsFeature,
                                       start_uid = feature_uid,
                                       end_uid = f2_uid,
                                       properties = { } )
    
    
    def __get_feature_label_and_uid( self, feature: SeqFeature, record_uid: str, location = None ):
        uid = feature.id
        label = str( feature.type )
        
        if uid:
            uid = "{}_{}_{}".format( label, record_uid, uid )
        else:
            if location is None:
                location = _LocationExtract( feature.location )
            
            uid = "{}_{}[{}:{}]".format( label, record_uid, location.start, location.end )
        
        return label, uid
    
    
    def _make_property_name( self, key, prefix = "_" ):
        return prefix + string_helper.make_name( key )
    
    
    __ALPHABET = None
    
    
    @classmethod
    def __alphabet( cls ):
        from Bio import Alphabet
        from Bio.Alphabet import IUPAC
        
        
        if cls.__ALPHABET:
            return cls.__ALPHABET
        else:
            cls.__ALPHABET = {
                Alphabet.SingleLetterAlphabet: "S",
                Alphabet.ProteinAlphabet     : "P",
                Alphabet.NucleotideAlphabet  : "N",
                Alphabet.DNAAlphabet         : "D",
                Alphabet.RNAAlphabet         : "R",
                Alphabet.SecondaryStructure  : "SS",
                Alphabet.ThreeLetterProtein  : "3P",
                IUPAC.ExtendedIUPACProtein   : "xp",
                IUPAC.IUPACProtein           : "p",
                IUPAC.IUPACAmbiguousDNA      : "ad",
                IUPAC.ExtendedIUPACDNA       : "xd",
                IUPAC.IUPACAmbiguousRNA      : "ar",
                IUPAC.IUPACUnambiguousRNA    : "ur" }
            
            return cls.__ALPHABET
    
    
    def _alphabet_shortcode( self, a: Optional[Alphabet] ) -> Optional[str]:
        """
        Use alphabet short-codes to avoid polluting the database with long strings
        """
        alphabet = self.__alphabet()
        if type( a ) in alphabet:
            return alphabet[type( a )]
        
        t = str( a )
        TRUNCATE = "Alphabet()"
        if t.endswith( TRUNCATE ):
            return t[0:-len( TRUNCATE )]
        else:
            return t
    
    
    def _get_unique_id( self, x: Reference ) -> str:
        """
        Since there doesn't seem to be any consistency in the journal formats, this creates one
        It won't work for even slightly different formats, but at least comes up with something that will work for the same file
        """
        
        if x.pubmed_id:
            return x.pubmed_id
        
        if x.medline_id:
            return x.medline_id
        
        author = string_helper.first_words( x.authors )
        title = string_helper.first_words( x.title )
        journal = string_helper.first_words( x.journal )
        
        return author + "/" + title + "/" + journal


class IsParserFilter:
    def __init__( self, name: str, code: str, extension: Union[str, List[str]], description: str, detect_records: Optional[str] = None ):
        """
        :param name: Inherited 
        :param code: BioPython parser code 
        :param extension: Inherited 
        :param description: Inherited 
        """
        self.name = name
        self.extension = extension
        self.description = description
        self.detect_records = detect_records
        self.code = code


# noinspection SpellCheckingInspection
_SEQUENCE_EXT = (IsParserFilter( "ABIF", "abif", ".abif", "Applied Biosystem's sequencing trace format" ),
                 IsParserFilter( "ACE", "ace", ".ace", "Reads the contig. sequences from an ACE assembly file." ),
                 IsParserFilter( "EMBL", "embl", ".embl", "The EMBL flat file format." ),
                 IsParserFilter( "FASTA", "fasta", ".fasta", "The generic sequence file format where each record starts with an identifier line starting with a \">\" character, followed by lines of sequence.", detect_records = ">.*" ),
                 IsParserFilter( "FASTQ", "fastq", ".fastq", "A \"FASTA like\" format used by Sanger which also stores PHRED sequence quality values (with an ASCII offset of 33)." ),
                 IsParserFilter( "FASTQ (Sanger)", "fastq-sanger", ".fastq-sanger", "An alias for \"fastq\" for consistency with BioPerl and EMBOSS" ),
                 IsParserFilter( "FASTQ (Solexa)", "fastq-solexa", ".fastq-solexa", "Original Solexa/Illumnia variant of the FASTQ format which encodes Solexa quality scores (not PHRED quality scores) with an ASCII offset of 64." ),
                 IsParserFilter( "FASTQ (Illumina)", "fastq-illumina", ".fastq-illumina", "Solexa/Illumina 1.3 to 1.7 variant of the FASTQ format which encodes PHRED quality scores with an ASCII offset of 64 (not 33). Note as of version 1.8 of the CASAVA pipeline Illumina will produce FASTQ files using the standard Sanger encoding." ),
                 IsParserFilter( "Genbank", "genbank", [".genbank", ".gbff", ".gb"], "The GenBank or GenPept flat file format.", detect_records = "//.*" ),
                 IsParserFilter( "IntelliGenetics", "ig", ".ig", "The IntelliGenetics file format, apparently the same as the MASE alignment format." ),
                 IsParserFilter( "IMGT", "imgt", ".imgt", "An EMBL like format from IMGT where the feature tables are more indented to allow for longer feature types." ),
                 IsParserFilter( "Protein Data Bank", "pdb-seqres", ".pdb-seqres", "Reads a Protein Data Bank (PDB) file to determine the complete protein sequence as it appears in the header (no dependencies)." ),
                 IsParserFilter( "Bio.PDB", "pdb-atom", ".pdb-atom", "Uses Bio.PDB to determine the (partial) protein sequence as it appears in the structure based on the atom coordinate section of the file (requires NumPy for Bio.PDB)." ),
                 IsParserFilter( "PHRED-output", "phd", ".phd", "Output from PHRED, used by PHRAP and CONSED for input." ),
                 IsParserFilter( "NBRF", "pir", ".pir", "A \"FASTA like\" format introduced by the National Biomedical Research Foundation (NBRF) for the Protein Information Resource (PIR) database, now part of UniProt." ),
                 IsParserFilter( "XML (SeqXML)", "seqxml", ".seqxml", "SeqXML, simple XML format described in Schmitt et al (2011)." ),
                 IsParserFilter( "SFF", "sff", ".sff", "Standard Flowgram Format (SFF), typical output from Roche 454." ),
                 IsParserFilter( "SFF (trimmed)", "sff-trim", ".sff-trim", "Standard Flowgram Format (SFF) with given trimming applied." ),
                 IsParserFilter( "XML (UniProt)", "swiss", ".swiss", "Plain text Swiss-Prot aka UniProt format." ),
                 IsParserFilter( "TSV", "tab", [".tab", ".tsv"], "Simple two column tab separated sequence files, where each line holds a record's identifier and sequence. For example , this is used as by Aligent's eArray software when saving microarray probes in a minimal tab delimited text file." ),
                 IsParserFilter( "Quality", "qual", ".qual", "A \"FASTA like\" format holding PHRED quality values from sequencing DNA, but no actual sequences (usually provided in separate FASTA files)." ),
                 IsParserFilter( "TXT (UniProt)", "uniprot-xml", ".uniprot-xml", "The UniProt XML format (replacement for the SwissProt plain text format which we call \"swiss\")" ))

_ULocation = Union[FeatureLocation, int, List[FeatureLocation], List[int]]
"""
Union of types that can be used to identify a location within a sequence.
"""


class _LocationExtract:
    def __init__( self, locations: _ULocation ):
        if type( locations ) is not list:
            locations = [locations]
        
        start = []
        end = []
        
        # noinspection PyTypeChecker
        for location in locations:
            if type( location ) is int:
                start.append( location )
                end.append( location )
            elif type( location ) in [FeatureLocation, CompoundLocation]:
                start.append( location.start )
                end.append( location.end )
            else:
                raise SwitchError( "location", location )
        
        self.start, self.start_type = self.__translate_location( start )
        self.end, self.end_type = self.__translate_location( end )
    
    
    @staticmethod
    def __translate_location( positions ) -> Tuple[List[int], List[str]]:
        indices = []
        types = []
        
        for i, v in enumerate( positions ):
            if isinstance( v, int ):  # BioPython positions inherit int
                types.append( type( v ).__name__ )
                indices.append( int( v ) )
            else:
                raise ValueError( "Don't know how to convert the location value «{0}» of type «{1}»".format( v, type( v ) ) )
        
        return indices, types


def _read_scientific_names_db( database: neocommand.Origin ) -> Dict[int, str]:
    with database.open_reader() as reader:
        return { int( k ): v for k, v in reader.on_read_all_props( "Taxon", "scientific_name" ) }



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/Users/martinrusilowicz/work/apps/bio42/bio42_gui/forms/designer/frm_transfer_designer.ui'
#
# Created by: PyQt5 UI code generator 5.9
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def __init__(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(697, 487)
        Dialog.setStyleSheet("/**\n"
"    PURPOSE:\n"
"        This is the default style-sheet used by all Intermake dialogues.\n"
"        It needs to be processed by css_processing.py before it can be used. \n"
"        It can be retrieved in processed form by the `intermake_gui.default_style_sheet()` function.\n"
"\n"
"    USAGE:    \n"
"        You can replace this stylesheet with your own.\n"
"        If you blank the contents of this stylesheet, the OSs default controls will be used.\n"
"        If you delete this stylesheet, the program will crash.\n"
"        \n"
"    EXTENSIONS:\n"
"        Normally not permitted in Qt, the following values are read through Intermake.\n"
"            * #DEFINE X Y                    - replaces all text `X` with `Y`\n"
"            * #WHEN X Y Z                    - only executes the following lines if the current\n"
"                                               section is any of `X` `Y` or `Z`.\n"
"                                               The section is specified when the user selects a\n"
"                                               stylesheet.\n"
"            * `QApplication.style`           - one of the Qt styles\n"
"            * `QApplication.small_icon_size` - the menu icon size, permitted only if `style` is set\n"
"            * `QMdiArea.background`          - colour of the Mdi area\n"
"\n"
"    DETAILS:\n"
"        Follow standard Qt stylesheet guidelines.\n"
"        \n"
"        The `:root` section defines constants that may be used elsewhere. These constants are\n"
"        substituted during the the processing stage and the `:root` section is removed.\n"
"        \n"
"        Intermake controls may have a string property named \"theme\" assigned to to certain widgets.\n"
"        This specifies that a unique appearance for the widget is intended:\n"
"        \n"
"        WIDGET        | THEME             | APPEARANCE (GUIDE)            | USAGE (GUIDE)\n"
"        --------------+-------------------+-------------------------------+-------------------------------\n"
"        QLabel        | heading           | border, big, bold             | section titles \n"
"        QLabel        | subheading        | border, big, bold             | section titles \n"
"        QTextEdit     | console           | monospaced, black background  | code, console output\n"
"        QPushButton   | completed         |                               |\n"
"        QPushButton   | cancel            | red                           | abort button\n"
"        QFrame        | header            | border                        | section titles\n"
"        QFrame        | contents          | white                         | with objects in\n"
"        QToolButton   | listbutton        | condensed                     | buttons in lists\n"
"        QToolButton   | help              | help icon                     | help buttons\n"
"        QLabel        | helpbox           | tooltip background            | help labels\n"
"        QLabel        | icon              | background suitable for image | label showing an icon\n"
"        QLabel        | warning           | yellow background, red text   | warning messages     \n"
"        QMdiArea      | empty             | darker                        | when MDI area has no windows\n"
"        QToolButton   | combo             | white                         | when button presents a selection menu\n"
"        QToolButton   | item              | white background, borderless  | button in a \"contents\" frame, like a list item\n"
"        QFrame        | helpbox           | yellow background             | frame contains help\n"
"*/\n"
"\n"
"\n"
"\n"
"QMdiArea\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"listbutton\"]\n"
"{\n"
"    background   : #40C0FF;\n"
"    border-style : outset;\n"
"    border-width : 2px;\n"
"    border-color : transparent;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::hover\n"
"{\n"
"    background   : #B0D5E8;\n"
"    border-color : blue;\n"
"}\n"
"\n"
"QToolButton[style=\"listbutton\"]::pressed\n"
"{\n"
"    background   : #0040C0;\n"
"    border-style : inset;\n"
"}\n"
"\n"
"QLabel[style=\"icon\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QFrame[style=\"title\"]\n"
"{\n"
"    margin-top     : 16px;\n"
"    margin-bottom  : 4px;\n"
"    margin-left    : 0px;\n"
"    margin-right   : 0px;\n"
"    border-radius  : 0px;\n"
"    border-bottom  : 2px solid silver;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    padding-top    : 2px;\n"
"    padding-bottom : 2px;\n"
"    padding-left   : -4px;\n"
"    padding-right  : 0px;\n"
"    color          : black;\n"
"    font-size      : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title\"], QFrame[style=\"title\"]\n"
"{\n"
"    background    : #EEEEEE;\n"
"    border-radius : 4px;\n"
"    margin        : 2px;\n"
"    padding       : 2px;\n"
"    color         : black;\n"
"    font-size     : 18px;\n"
"}\n"
"\n"
"QLabel[style=\"title-embeded\"]\n"
"{\n"
"    background : #EEEEEE;\n"
"    color      : black;\n"
"    font-size  : 18px;\n"
"}\n"
"\n"
"\n"
"\n"
"\n"
"QLabel[style=\"helpbox\"]\n"
"{\n"
"    background    : transparent;\n"
"    color         : steelblue;\n"
"    padding       : 2px;\n"
"    border-radius : 4px;\n"
"}\n"
"\n"
"QLabel[style=\"subheading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    font-style: italic;\n"
"}\n"
"\n"
"QLabel[style=\"heading\"], QPushButton[style=\"heading\"]\n"
"{\n"
"    font-weight: bold;\n"
"    border-bottom  : 1px solid #404040;\n"
"    border-left    : none;\n"
"    border-right   : none;\n"
"    border-top     : none;\n"
"    color: #404040;\n"
"}\n"
"\n"
"\n"
"QTextEdit[style=\"console\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"    background : black;\n"
"    color      : white;\n"
"}\n"
"\n"
"QTextEdit[style=\"monospaced\"]\n"
"{\n"
"    font-family: \"Consolas\", monospace;\n"
"}\n"
"\n"
"QPushButton[style=\"completed\"]\n"
"{\n"
"    background    : #00C080;\n"
"    border-color  : #00C080; \n"
"}\n"
"\n"
"QPushButton[style=\"cancel\"]\n"
"{\n"
"    background    : #C00000;\n"
"    color         : white;\n"
"    padding       : 8px;\n"
"    border-color  : white;\n"
"    border-width  : 1px;\n"
"    border-radius : 8px;\n"
"}\n"
"\n"
"QMdiArea[style=\"empty\"]\n"
"{\n"
"    background : #E0E0E0;\n"
"}\n"
"\n"
"QLabel[style=\"warning\"]\n"
"{\n"
"    background       : #FFFFD0;\n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"    image            : url(\":/intermake/warning.svg\");\n"
"    image-position   : left;\n"
"    qproperty-indent : 24;\n"
"}\n"
"\n"
"QLabel[style=\"warning_no_icon\"]\n"
"{\n"
"    background       : #FFFF80;\n"
"    color            : #800000;          \n"
"    padding          : 8px;\n"
"    border-radius    : 8px;\n"
"}\n"
"\n"
"QToolButton[style=\"dropdown\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/dropdown.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"refresh\"]\n"
"{\n"
"    qproperty-toolButtonStyle : ToolButtonTextBesideIcon;\n"
"    qproperty-icon            : url(:/intermake/refresh.svg);\n"
"}\n"
"\n"
"\n"
"QToolButton[style=\"combo\"]\n"
"{\n"
"    background: white;\n"
"}\n"
"\n"
"QFrame[style=\"contents\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]\n"
"{\n"
"    background: white;\n"
"    border: 1px solid white;\n"
"    color: black;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"    border: 1px dotted #8080FF;\n"
"}\n"
"\n"
"QToolButton[style=\"item\"]:pressed\n"
"{\n"
"    background: #B0D5E8;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]\n"
"{\n"
"    border: 1px solid transparent;\n"
"    background: transparent;\n"
"    qproperty-icon            : url(:/intermake/help.svg);\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:hover\n"
"{\n"
"    border: 1px outset silver;\n"
"}\n"
"\n"
"QToolButton[style=\"help\"]:pressed\n"
"{\n"
"    border: 1px inset silver;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]\n"
"{\n"
"    background: transparent;\n"
"    border: none;\n"
"    color: blue;\n"
"    padding: 4px;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:hover\n"
"{\n"
"    color: blue;\n"
"    text-decoration: underline;\n"
"}\n"
"\n"
"QPushButton[style=\"link\"]:pressed\n"
"{\n"
"    color: red;\n"
"    text-decoration: underline;\n"
"    border: 1px solid blue;\n"
"}\n"
"")
        self.verticalLayout = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout.setObjectName("verticalLayout")
        self.LBL_TITLE = QtWidgets.QLabel(Dialog)
        self.LBL_TITLE.setObjectName("LBL_TITLE")
        self.verticalLayout.addWidget(self.LBL_TITLE)
        self.LBL_SOURCE = QtWidgets.QLabel(Dialog)
        self.LBL_SOURCE.setObjectName("LBL_SOURCE")
        self.verticalLayout.addWidget(self.LBL_SOURCE)
        self.CMB_SOURCE = QtWidgets.QComboBox(Dialog)
        self.CMB_SOURCE.setObjectName("CMB_SOURCE")
        self.verticalLayout.addWidget(self.CMB_SOURCE)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setSpacing(0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem = QtWidgets.QSpacerItem(32, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem)
        self.horizontalFrame = QtWidgets.QFrame(Dialog)
        self.horizontalFrame.setFrameShape(QtWidgets.QFrame.Panel)
        self.horizontalFrame.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.horizontalFrame.setProperty("style", "helpbox")
        self.horizontalFrame.setObjectName("horizontalFrame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.horizontalFrame)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.LBL_SOURCE_5 = QtWidgets.QLabel(self.horizontalFrame)
        self.LBL_SOURCE_5.setMinimumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_5.setMaximumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_5.setText("")
        self.LBL_SOURCE_5.setPixmap(QtGui.QPixmap(":/bio42/information.svg"))
        self.LBL_SOURCE_5.setScaledContents(True)
        self.LBL_SOURCE_5.setObjectName("LBL_SOURCE_5")
        self.horizontalLayout.addWidget(self.LBL_SOURCE_5)
        self.LBL_SRC_INFO = QtWidgets.QLabel(self.horizontalFrame)
        self.LBL_SRC_INFO.setProperty("style", "helpbox")
        self.LBL_SRC_INFO.setObjectName("LBL_SRC_INFO")
        self.horizontalLayout.addWidget(self.LBL_SRC_INFO)
        self.horizontalLayout_4.addWidget(self.horizontalFrame)
        self.verticalLayout.addLayout(self.horizontalLayout_4)
        self.LBL_DEST = QtWidgets.QLabel(Dialog)
        self.LBL_DEST.setObjectName("LBL_DEST")
        self.verticalLayout.addWidget(self.LBL_DEST)
        self.CMB_DEST = QtWidgets.QComboBox(Dialog)
        self.CMB_DEST.setObjectName("CMB_DEST")
        self.verticalLayout.addWidget(self.CMB_DEST)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setSpacing(0)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        spacerItem1 = QtWidgets.QSpacerItem(32, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_5.addItem(spacerItem1)
        self.horizontalFrame_2 = QtWidgets.QFrame(Dialog)
        self.horizontalFrame_2.setFrameShape(QtWidgets.QFrame.Panel)
        self.horizontalFrame_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.horizontalFrame_2.setProperty("style", "helpbox")
        self.horizontalFrame_2.setObjectName("horizontalFrame_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.horizontalFrame_2)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.LBL_SOURCE_6 = QtWidgets.QLabel(self.horizontalFrame_2)
        self.LBL_SOURCE_6.setMinimumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_6.setMaximumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_6.setText("")
        self.LBL_SOURCE_6.setPixmap(QtGui.QPixmap(":/bio42/information.svg"))
        self.LBL_SOURCE_6.setScaledContents(True)
        self.LBL_SOURCE_6.setObjectName("LBL_SOURCE_6")
        self.horizontalLayout_2.addWidget(self.LBL_SOURCE_6)
        self.LBL_DEST_INFO = QtWidgets.QLabel(self.horizontalFrame_2)
        self.LBL_DEST_INFO.setProperty("style", "helpbox")
        self.LBL_DEST_INFO.setObjectName("LBL_DEST_INFO")
        self.horizontalLayout_2.addWidget(self.LBL_DEST_INFO)
        self.horizontalLayout_5.addWidget(self.horizontalFrame_2)
        self.verticalLayout.addLayout(self.horizontalLayout_5)
        self.LBL_PROTO = QtWidgets.QLabel(Dialog)
        self.LBL_PROTO.setObjectName("LBL_PROTO")
        self.verticalLayout.addWidget(self.LBL_PROTO)
        self.CBM_PROTO = QtWidgets.QComboBox(Dialog)
        self.CBM_PROTO.setObjectName("CBM_PROTO")
        self.verticalLayout.addWidget(self.CBM_PROTO)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setSpacing(0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        spacerItem2 = QtWidgets.QSpacerItem(32, 20, QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem2)
        self.horizontalFrame_3 = QtWidgets.QFrame(Dialog)
        self.horizontalFrame_3.setFrameShape(QtWidgets.QFrame.Panel)
        self.horizontalFrame_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.horizontalFrame_3.setObjectName("horizontalFrame_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.horizontalFrame_3)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.LBL_SOURCE_7 = QtWidgets.QLabel(self.horizontalFrame_3)
        self.LBL_SOURCE_7.setMinimumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_7.setMaximumSize(QtCore.QSize(24, 24))
        self.LBL_SOURCE_7.setText("")
        self.LBL_SOURCE_7.setPixmap(QtGui.QPixmap(":/bio42/information.svg"))
        self.LBL_SOURCE_7.setScaledContents(True)
        self.LBL_SOURCE_7.setObjectName("LBL_SOURCE_7")
        self.horizontalLayout_3.addWidget(self.LBL_SOURCE_7)
        self.LBL_PROTO_INFO = QtWidgets.QLabel(self.horizontalFrame_3)
        self.LBL_PROTO_INFO.setProperty("style", "helpbox")
        self.LBL_PROTO_INFO.setObjectName("LBL_PROTO_INFO")
        self.horizontalLayout_3.addWidget(self.LBL_PROTO_INFO)
        self.horizontalLayout_6.addWidget(self.horizontalFrame_3)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem3)
        self.BTNBOX_MAIN = QtWidgets.QDialogButtonBox(Dialog)
        self.BTNBOX_MAIN.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.BTNBOX_MAIN.setObjectName("BTNBOX_MAIN")
        self.verticalLayout.addWidget(self.BTNBOX_MAIN)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Dialog"))
        self.LBL_TITLE.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_TITLE.setText(_translate("Dialog", "Graph transfer"))
        self.LBL_TITLE.setProperty("style", _translate("Dialog", "title"))
        self.LBL_SOURCE.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_SOURCE.setText(_translate("Dialog", "Source"))
        self.LBL_SOURCE.setProperty("style", _translate("Dialog", "heading"))
        self.CMB_SOURCE.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_SOURCE_5.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_SRC_INFO.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_SRC_INFO.setText(_translate("Dialog", "Information"))
        self.LBL_DEST.setToolTip(_translate("Dialog", "Select where to send the data to. Click the help button for more information about the selected destination."))
        self.LBL_DEST.setText(_translate("Dialog", "Destination"))
        self.LBL_DEST.setProperty("style", _translate("Dialog", "heading"))
        self.CMB_DEST.setToolTip(_translate("Dialog", "Select where to send the data to. Click the help button for more information about the selected destination."))
        self.LBL_SOURCE_6.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_DEST_INFO.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_DEST_INFO.setText(_translate("Dialog", "Information"))
        self.LBL_PROTO.setToolTip(_translate("Dialog", "Select how to transfer the data. Click the help button for more information about the selected protocol."))
        self.LBL_PROTO.setText(_translate("Dialog", "Protocol"))
        self.LBL_PROTO.setProperty("style", _translate("Dialog", "heading"))
        self.CBM_PROTO.setToolTip(_translate("Dialog", "Select how to transfer the data. Click the help button for more information about the selected protocol."))
        self.horizontalFrame_3.setProperty("style", _translate("Dialog", "helpbox"))
        self.LBL_SOURCE_7.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_PROTO_INFO.setToolTip(_translate("Dialog", "Select where to acquire the data from. Click the help button for more information about the selected source."))
        self.LBL_PROTO_INFO.setText(_translate("Dialog", "Information"))


